@@ -22,10 +22,12 @@
 #include "itkObject.h"
 #include "itkObjectFactory.h"
 
+#include "OTBOSSIMAdaptersExport.h"
+
 namespace otb
 {
 
-class DEMConvertAdapter: public itk::Object
+class OTBOSSIMAdapters_EXPORT DEMConvertAdapter: public itk::Object
 {
 public:
   /** Standard class typedefs. */
