@@ -750,53 +750,53 @@ FormosatImageMetadataInterface
     {
     const float b0[281] =
     {
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0.000219376,   0.000219425,   0.000231534,   0.000284519,
-     0.000550079,   0.001,   0.003,   0.006,   0.012,   0.0235,
-     0.035,   0.043,   0.0503893,   0.0525,   0.055,   0.0565,
-     0.058,   0.059,   0.059,   0.0608594,   0.061,   0.0615,
-     0.062,   0.063,   0.063,   0.064,   0.063,   0.064,
-     0.065,   0.066,   0.066,   0.066,   0.066,   0.0675,
-     0.069,   0.0708104,   0.0709615,   0.0709001,   0.071,   0.0715,
-     0.073,   0.074,   0.074,   0.073,   0.073,   0.0735,
-     0.075,   0.0765,   0.078,   0.078,   0.078,   0.0785,
-     0.0800145,   0.0815,   0.083,   0.083,   0.083,   0.083,
-     0.083,   0.0835,   0.085,   0.0865,   0.087,   0.088,
-     0.087,   0.087,   0.088,   0.0885,   0.0907023,   0.0915,
-     0.092,   0.092,   0.092,   0.092,   0.093,   0.094,
-     0.095,   0.096,   0.096,   0.096,   0.095,   0.095,
-     0.095,   0.095,   0.096,   0.0975,   0.098,   0.099,
-     0.099,   0.098,   0.098,   0.0965,   0.096,   0.0965,
-     0.098,   0.0985,   0.099,   0.0995,   0.099,   0.0975,
-     0.097,   0.0955,   0.095,   0.095,   0.095,   0.0965,
-     0.097,   0.098,   0.098,   0.0975,   0.097,   0.096,
-     0.095,   0.095,   0.094,   0.094,   0.095,   0.0955,
-     0.096,   0.097,   0.097,   0.097,   0.097,   0.097,
-     0.097,   0.096,   0.097,   0.097,   0.097,   0.098,
-     0.098,   0.096,   0.095,   0.094,   0.093,   0.092,
-     0.091,   0.0905658,   0.089,   0.089,   0.089,   0.088,
-     0.088,   0.0875,   0.087,   0.086,   0.085,   0.084,
-     0.083,   0.0825,   0.082,   0.081,   0.081,   0.0804051,
-     0.079,   0.078,   0.077,   0.077,   0.076,   0.075,
-     0.074,   0.0735,   0.073,   0.0725,   0.072,   0.071,
-     0.071,   0.0704136,   0.069,   0.0685,   0.068,   0.067,
-     0.066,   0.0645,   0.063,   0.062,   0.0607892,   0.059,
-     0.058,   0.057,   0.056,   0.0545,   0.052,   0.0455,
-     0.038,   0.0286994,   0.0202138,   0.0125,   0.007,   0.004,
-     0.002,   0.001,   0.000909856,   0.000512159,   0.000357051,   0.00029112,
-     0.000215752,   0.000187213,   0.000171918,   0.000169724,   0.000166392,   0.000163058,
-     0.000159726,   0.000156393,   0.000153061,   0.000149728,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.000219376f,   0.000219425f,   0.000231534f,   0.000284519f,
+     0.000550079f,   0.001f,   0.003f,   0.006f,   0.012f,   0.0235f,
+     0.035f,   0.043f,   0.0503893f,   0.0525f,   0.055f,   0.0565f,
+     0.058f,   0.059f,   0.059f,   0.0608594f,   0.061f,   0.0615f,
+     0.062f,   0.063f,   0.063f,   0.064f,   0.063f,   0.064f,
+     0.065f,   0.066f,   0.066f,   0.066f,   0.066f,   0.0675f,
+     0.069f,   0.0708104f,   0.0709615f,   0.0709001f,   0.071f,   0.0715f,
+     0.073f,   0.074f,   0.074f,   0.073f,   0.073f,   0.0735f,
+     0.075f,   0.0765f,   0.078f,   0.078f,   0.078f,   0.0785f,
+     0.0800145f,   0.0815f,   0.083f,   0.083f,   0.083f,   0.083f,
+     0.083f,   0.0835f,   0.085f,   0.0865f,   0.087f,   0.088f,
+     0.087f,   0.087f,   0.088f,   0.0885f,   0.0907023f,   0.0915f,
+     0.092f,   0.092f,   0.092f,   0.092f,   0.093f,   0.094f,
+     0.095f,   0.096f,   0.096f,   0.096f,   0.095f,   0.095f,
+     0.095f,   0.095f,   0.096f,   0.0975f,   0.098f,   0.099f,
+     0.099f,   0.098f,   0.098f,   0.0965f,   0.096f,   0.0965f,
+     0.098f,   0.0985f,   0.099f,   0.0995f,   0.099f,   0.0975f,
+     0.097f,   0.0955f,   0.095f,   0.095f,   0.095f,   0.0965f,
+     0.097f,   0.098f,   0.098f,   0.0975f,   0.097f,   0.096f,
+     0.095f,   0.095f,   0.094f,   0.094f,   0.095f,   0.0955f,
+     0.096f,   0.097f,   0.097f,   0.097f,   0.097f,   0.097f,
+     0.097f,   0.096f,   0.097f,   0.097f,   0.097f,   0.098f,
+     0.098f,   0.096f,   0.095f,   0.094f,   0.093f,   0.092f,
+     0.091f,   0.0905658f,   0.089f,   0.089f,   0.089f,   0.088f,
+     0.088f,   0.0875f,   0.087f,   0.086f,   0.085f,   0.084f,
+     0.083f,   0.0825f,   0.082f,   0.081f,   0.081f,   0.0804051f,
+     0.079f,   0.078f,   0.077f,   0.077f,   0.076f,   0.075f,
+     0.074f,   0.0735f,   0.073f,   0.0725f,   0.072f,   0.071f,
+     0.071f,   0.0704136f,   0.069f,   0.0685f,   0.068f,   0.067f,
+     0.066f,   0.0645f,   0.063f,   0.062f,   0.0607892f,   0.059f,
+     0.058f,   0.057f,   0.056f,   0.0545f,   0.052f,   0.0455f,
+     0.038f,   0.0286994f,   0.0202138f,   0.0125f,   0.007f,   0.004f,
+     0.002f,   0.001f,   0.000909856f,   0.000512159f,   0.000357051f,   0.00029112f,
+     0.000215752f,   0.000187213f,   0.000171918f,   0.000169724f,   0.000166392f,   0.000163058f,
+     0.000159726f,   0.000156393f,   0.000153061f,   0.000149728f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f
     };
 
     //add panchromatic band to the temporary list
@@ -807,206 +807,206 @@ FormosatImageMetadataInterface
     {
     const float b1[281] =
     {
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0.000354959,   0.000354603,   0.000376745,   0.000478212,
-     0.0009718,   0.002,   0.005,   0.0124297,   0.024,   0.0415,
-     0.057,   0.0685,   0.074,   0.074,   0.076,   0.0795695,
-     0.082,   0.084,   0.083,   0.0825,   0.086,   0.0910953,
-     0.094,   0.096,   0.096,   0.094,   0.094,   0.096,
-     0.099,   0.0995,   0.099,   0.098,   0.095,   0.092,
-     0.095,   0.0985,   0.092,   0.0695,   0.037,   0.025,
-     0.009,   0.0025,   0.001,   0.000847053,   0.000588401,   0.00051966,
-     0.00050602,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.000354959f,   0.000354603f,   0.000376745f,   0.000478212f,
+     0.0009718f,   0.002f,   0.005f,   0.0124297f,   0.024f,   0.0415f,
+     0.057f,   0.0685f,   0.074f,   0.074f,   0.076f,   0.0795695f,
+     0.082f,   0.084f,   0.083f,   0.0825f,   0.086f,   0.0910953f,
+     0.094f,   0.096f,   0.096f,   0.094f,   0.094f,   0.096f,
+     0.099f,   0.0995f,   0.099f,   0.098f,   0.095f,   0.092f,
+     0.095f,   0.0985f,   0.092f,   0.0695f,   0.037f,   0.025f,
+     0.009f,   0.0025f,   0.001f,   0.000847053f,   0.000588401f,   0.00051966f,
+     0.00050602f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0
     };
 
     const float b2[281] =
     {
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0.000324677,   0.000326475,   0.000331943,   0.000386303,
-     0.000447683,   0.001,   0.003,   0.0045,   0.012,   0.0205,
-     0.036,   0.0615,   0.075,   0.081,   0.082,   0.0845,
-     0.087,   0.0885,   0.088,   0.087,   0.086,   0.0875,
-     0.0908484,   0.0925,   0.094,   0.094,   0.093,   0.0925,
-     0.093,   0.0955,   0.097,   0.098,   0.099,   0.099,
-     0.099,   0.099,   0.099,   0.099,   0.095,   0.0815,
-     0.057,   0.032,   0.018,   0.0112534,   0.005,   0.0015,
-     0.000758484,   0.000604297,   0.000512471,   0.000475316,   0.000453283,   0.00044559,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.000324677f,   0.000326475f,   0.000331943f,   0.000386303f,
+     0.000447683f,   0.001f,   0.003f,   0.0045f,   0.012f,   0.0205f,
+     0.036f,   0.0615f,   0.075f,   0.081f,   0.082f,   0.0845f,
+     0.087f,   0.0885f,   0.088f,   0.087f,   0.086f,   0.0875f,
+     0.0908484f,   0.0925f,   0.094f,   0.094f,   0.093f,   0.0925f,
+     0.093f,   0.0955f,   0.097f,   0.098f,   0.099f,   0.099f,
+     0.099f,   0.099f,   0.099f,   0.099f,   0.095f,   0.0815f,
+     0.057f,   0.032f,   0.018f,   0.0112534f,   0.005f,   0.0015f,
+     0.000758484f,   0.000604297f,   0.000512471f,   0.000475316f,   0.000453283f,   0.00044559f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0
     };
 
     const float b3[281] =
     {
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0.000461752,
-     0.001,   0.001,   0.003,   0.006,   0.013,   0.0335,
-     0.063,   0.089,   0.098,   0.099,   0.099,   0.099,
-     0.099,   0.0985,   0.097,   0.0945,   0.092,   0.0906796,
-     0.089,   0.0907659,   0.093,   0.0965,   0.1,   0.097,
-     0.091,   0.0865,   0.086,   0.0910438,   0.094,   0.092,
-     0.093,   0.088,   0.064,   0.034,   0.015,   0.0075,
-     0.006,   0.0045,   0.003,   0.001,   0.000607601,   0.000202927,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.000461752f,
+     0.001f,   0.001f,   0.003f,   0.006f,   0.013f,   0.0335f,
+     0.063f,   0.089f,   0.098f,   0.099f,   0.099f,   0.099f,
+     0.099f,   0.0985f,   0.097f,   0.0945f,   0.092f,   0.0906796f,
+     0.089f,   0.0907659f,   0.093f,   0.0965f,   0.1f,   0.097f,
+     0.091f,   0.0865f,   0.086f,   0.0910438f,   0.094f,   0.092f,
+     0.093f,   0.088f,   0.064f,   0.034f,   0.015f,   0.0075f,
+     0.006f,   0.0045f,   0.003f,   0.001f,   0.000607601f,   0.000202927f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0
     };
 
     const float b4[281] =
     {
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0.000481456,   0.00071923,   0.00098303,   0.001,   0.000947915,
-     0.00090899,   0.000887367,   0.000576847,   0.000470858,   0.00052246,   0.000713811,
-     0.001,   0.0015,   0.003,   0.005,   0.008,   0.0145,
-     0.022,   0.035,   0.049,   0.0595,   0.075,   0.0905,
-     0.098,   0.0995,   0.097,   0.093,   0.091,   0.0925,
-     0.094,   0.096,   0.096,   0.0955,   0.094,   0.092,
-     0.0907811,   0.089,   0.088,   0.088,   0.088,   0.088,
-     0.088,   0.0875,   0.087,   0.086,   0.085,   0.084,
-     0.083,   0.083,   0.082,   0.081,   0.0806396,   0.079,
-     0.078,   0.077,   0.076,   0.075,   0.074,   0.073,
-     0.072,   0.071,   0.0700369,   0.0685,   0.067,   0.0655,
-     0.064,   0.063,   0.063,   0.062,   0.059,   0.054,
-     0.043,   0.034,   0.025,   0.016,   0.009,   0.0055,
-     0.003,   0.0015,   0.001,   0.000691333,   0.000432126,   0.000356974,
-     0.000265441,   0.000219773,   0.000195346,   0.000192716,   0.000188932,   0.000185148,
-     0.000181364,   0.00017758,   0.000173796,   0.000170011,   0.000166227,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.000481456f,   0.00071923f,   0.00098303f,   0.001f,   0.000947915f,
+     0.00090899f,   0.000887367f,   0.000576847f,   0.000470858f,   0.00052246f,   0.000713811f,
+     0.001f,   0.0015f,   0.003f,   0.005f,   0.008f,   0.0145f,
+     0.022f,   0.035f,   0.049f,   0.0595f,   0.075f,   0.0905f,
+     0.098f,   0.0995f,   0.097f,   0.093f,   0.091f,   0.0925f,
+     0.094f,   0.096f,   0.096f,   0.0955f,   0.094f,   0.092f,
+     0.0907811f,   0.089f,   0.088f,   0.088f,   0.088f,   0.088f,
+     0.088f,   0.0875f,   0.087f,   0.086f,   0.085f,   0.084f,
+     0.083f,   0.083f,   0.082f,   0.081f,   0.0806396f,   0.079f,
+     0.078f,   0.077f,   0.076f,   0.075f,   0.074f,   0.073f,
+     0.072f,   0.071f,   0.0700369f,   0.0685f,   0.067f,   0.0655f,
+     0.064f,   0.063f,   0.063f,   0.062f,   0.059f,   0.054f,
+     0.043f,   0.034f,   0.025f,   0.016f,   0.009f,   0.0055f,
+     0.003f,   0.0015f,   0.001f,   0.000691333f,   0.000432126f,   0.000356974f,
+     0.000265441f,   0.000219773f,   0.000195346f,   0.000192716f,   0.000188932f,   0.000185148f,
+     0.000181364f,   0.00017758f,   0.000173796f,   0.000170011f,   0.000166227f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0
     };
 
     //Add multispectral bands to the temporary list
