@@ -786,60 +786,60 @@ QuickBirdImageMetadataInterface
     {
     const float b0[321] =
     {
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0.0007015,   0.001403,   0.001291,   0.001179,   0.0011415,
-     0.001104,   0.00101145,   0.0009189,   0.00104845,   0.001178,   0.0016055,
-     0.002033,   0.0044495,   0.006866,   0.008873,   0.01088,   0.013805,
-     0.01673,   0.021325,   0.02592,   0.03106,   0.0362,   0.043415,
-     0.05063,   0.05879,   0.06695,   0.075765,   0.08458,   0.09389,
-     0.1032,   0.11255,   0.1219,   0.13345,   0.145,   0.1567,
-     0.1684,   0.17895,   0.1895,   0.2011,   0.2127,   0.21625,
-     0.2198,   0.2392,   0.2586,   0.26695,   0.2753,   0.2854,
-     0.2955,   0.30545,   0.3154,   0.3259,   0.3364,   0.341,
-     0.3456,   0.3501,   0.3546,   0.35785,   0.3611,   0.3648,
-     0.3685,   0.3733,   0.3781,   0.3875,   0.3969,   0.4055,
-     0.4141,   0.42755,   0.441,   0.4543,   0.4676,   0.4829,
-     0.4982,   0.5167,   0.5352,   0.5532,   0.5712,   0.59245,
-     0.6137,   0.6382,   0.6627,   0.6839,   0.7051,   0.7275,
-     0.7499,   0.77045,   0.791,   0.81055,   0.8301,   0.8465,
-     0.8629,   0.877,   0.8911,   0.9081,   0.9251,   0.9293,
-     0.9335,   0.94265,   0.9518,   0.95695,   0.9621,   0.96095,
-     0.9598,   0.97525,   0.9907,   0.9941,   0.9975,   0.9922,
-     0.9869,   0.99345,   1,   0.9938,   0.9876,   0.9877,
-     0.9878,   0.977,   0.9662,   0.95725,   0.9483,   0.934,
-     0.9197,   0.919,   0.9183,   0.90635,   0.8944,   0.8912,
-     0.888,   0.88305,   0.8781,   0.8865,   0.8949,   0.8921,
-     0.8893,   0.8858,   0.8823,   0.88695,   0.8916,   0.8848,
-     0.878,   0.8879,   0.8978,   0.8933,   0.8888,   0.8801,
-     0.8714,   0.86905,   0.8667,   0.8677,   0.8687,   0.86995,
-     0.8712,   0.86685,   0.8625,   0.87175,   0.881,   0.8814,
-     0.8818,   0.8897,   0.8976,   0.9024,   0.9072,   0.91835,
-     0.9295,   0.93105,   0.9326,   0.9198,   0.907,   0.91305,
-     0.9191,   0.9173,   0.9155,   0.9097,   0.9039,   0.89875,
-     0.8936,   0.88705,   0.8805,   0.8761,   0.8717,   0.8605,
-     0.8493,   0.8475,   0.8457,   0.8505,   0.8553,   0.85675,
-     0.8582,   0.85825,   0.8583,   0.8627,   0.8671,   0.8505,
-     0.8339,   0.83895,   0.844,   0.847,   0.85,   0.85265,
-     0.8553,   0.8447,   0.8341,   0.83675,   0.8394,   0.8235,
-     0.8076,   0.8091,   0.8106,   0.785,   0.7594,   0.7616,
-     0.7638,   0.749,   0.7342,   0.7204,   0.7066,   0.70035,
-     0.6941,   0.67875,   0.6634,   0.65895,   0.6545,   0.63655,
-     0.6186,   0.60945,   0.6003,   0.5961,   0.5919,   0.58315,
-     0.5744,   0.55265,   0.5309,   0.5139,   0.4969,   0.48835,
-     0.4798,   0.46305,   0.4463,   0.4305,   0.4147,   0.40975,
-     0.4048,   0.3893,   0.3738,   0.3593,   0.3448,   0.3283,
-     0.3118,   0.3035,   0.2952,   0.28405,   0.2729,   0.2648,
-     0.2567,   0.24975,   0.2428,   0.2322,   0.2216,   0.21615,
-     0.2107,   0.2039,   0.1971,   0.18735,   0.1776,   0.1703,
-     0.163,   0.15575,   0.1485,   0.14215,   0.1358,   0.1299,
-     0.124,   0.11625,   0.1085,   0.10197,   0.09544,   0.08927,
-     0.0831,   0.077305,   0.07151,   0.06746,   0.06341,   0.05911,
-     0.05481,   0.051195,   0.04758,   0.02882,   0.01006,   0.00503,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0007015f,   0.001403f,   0.001291f,   0.001179f,   0.0011415f,
+     0.001104f,   0.00101145f,   0.0009189f,   0.00104845f,   0.001178f,   0.0016055f,
+     0.002033f,   0.0044495f,   0.006866f,   0.008873f,   0.01088f,   0.013805f,
+     0.01673f,   0.021325f,   0.02592f,   0.03106f,   0.0362f,   0.043415f,
+     0.05063f,   0.05879f,   0.06695f,   0.075765f,   0.08458f,   0.09389f,
+     0.1032f,   0.11255f,   0.1219f,   0.13345f,   0.145f,   0.1567f,
+     0.1684f,   0.17895f,   0.1895f,   0.2011f,   0.2127f,   0.21625f,
+     0.2198f,   0.2392f,   0.2586f,   0.26695f,   0.2753f,   0.2854f,
+     0.2955f,   0.30545f,   0.3154f,   0.3259f,   0.3364f,   0.341f,
+     0.3456f,   0.3501f,   0.3546f,   0.35785f,   0.3611f,   0.3648f,
+     0.3685f,   0.3733f,   0.3781f,   0.3875f,   0.3969f,   0.4055f,
+     0.4141f,   0.42755f,   0.441f,   0.4543f,   0.4676f,   0.4829f,
+     0.4982f,   0.5167f,   0.5352f,   0.5532f,   0.5712f,   0.59245f,
+     0.6137f,   0.6382f,   0.6627f,   0.6839f,   0.7051f,   0.7275f,
+     0.7499f,   0.77045f,   0.791f,   0.81055f,   0.8301f,   0.8465f,
+     0.8629f,   0.877f,   0.8911f,   0.9081f,   0.9251f,   0.9293f,
+     0.9335f,   0.94265f,   0.9518f,   0.95695f,   0.9621f,   0.96095f,
+     0.9598f,   0.97525f,   0.9907f,   0.9941f,   0.9975f,   0.9922f,
+     0.9869f,   0.99345f,   1.0f,   0.9938f,   0.9876f,   0.9877f,
+     0.9878f,   0.977f,   0.9662f,   0.95725f,   0.9483f,   0.934f,
+     0.9197f,   0.919f,   0.9183f,   0.90635f,   0.8944f,   0.8912f,
+     0.888f,   0.88305f,   0.8781f,   0.8865f,   0.8949f,   0.8921f,
+     0.8893f,   0.8858f,   0.8823f,   0.88695f,   0.8916f,   0.8848f,
+     0.878f,   0.8879f,   0.8978f,   0.8933f,   0.8888f,   0.8801f,
+     0.8714f,   0.86905f,   0.8667f,   0.8677f,   0.8687f,   0.86995f,
+     0.8712f,   0.86685f,   0.8625f,   0.87175f,   0.881f,   0.8814f,
+     0.8818f,   0.8897f,   0.8976f,   0.9024f,   0.9072f,   0.91835f,
+     0.9295f,   0.93105f,   0.9326f,   0.9198f,   0.907f,   0.91305f,
+     0.9191f,   0.9173f,   0.9155f,   0.9097f,   0.9039f,   0.89875f,
+     0.8936f,   0.88705f,   0.8805f,   0.8761f,   0.8717f,   0.8605f,
+     0.8493f,   0.8475f,   0.8457f,   0.8505f,   0.8553f,   0.85675f,
+     0.8582f,   0.85825f,   0.8583f,   0.8627f,   0.8671f,   0.8505f,
+     0.8339f,   0.83895f,   0.844f,   0.847f,   0.85f,   0.85265f,
+     0.8553f,   0.8447f,   0.8341f,   0.83675f,   0.8394f,   0.8235f,
+     0.8076f,   0.8091f,   0.8106f,   0.785f,   0.7594f,   0.7616f,
+     0.7638f,   0.749f,   0.7342f,   0.7204f,   0.7066f,   0.70035f,
+     0.6941f,   0.67875f,   0.6634f,   0.65895f,   0.6545f,   0.63655f,
+     0.6186f,   0.60945f,   0.6003f,   0.5961f,   0.5919f,   0.58315f,
+     0.5744f,   0.55265f,   0.5309f,   0.5139f,   0.4969f,   0.48835f,
+     0.4798f,   0.46305f,   0.4463f,   0.4305f,   0.4147f,   0.40975f,
+     0.4048f,   0.3893f,   0.3738f,   0.3593f,   0.3448f,   0.3283f,
+     0.3118f,   0.3035f,   0.2952f,   0.28405f,   0.2729f,   0.2648f,
+     0.2567f,   0.24975f,   0.2428f,   0.2322f,   0.2216f,   0.21615f,
+     0.2107f,   0.2039f,   0.1971f,   0.18735f,   0.1776f,   0.1703f,
+     0.163f,   0.15575f,   0.1485f,   0.14215f,   0.1358f,   0.1299f,
+     0.124f,   0.11625f,   0.1085f,   0.10197f,   0.09544f,   0.08927f,
+     0.0831f,   0.077305f,   0.07151f,   0.06746f,   0.06341f,   0.05911f,
+     0.05481f,   0.051195f,   0.04758f,   0.02882f,   0.01006f,   0.00503f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f
     };
 
     //add panchromatic band to the temporary list
@@ -850,234 +850,234 @@ QuickBirdImageMetadataInterface
     {
     const float b1[321] =
     {
-     0,   4.816e-11,   9.632e-11,   1.4606e-10,   1.958e-10,   2.4715e-10,
-     2.985e-10,   3.514e-10,   4.043e-10,   0.000505,   0.00101,   0.0015305,
-     0.002051,   0.002587,   0.003123,   0.0036745,   0.004226,   0.0043815,
-     0.004537,   0.0049295,   0.005322,   0.0046895,   0.004057,   0.003661,
-     0.003265,   0.002984,   0.002703,   0.002503,   0.002303,   0.0017815,
-     0.00126,   0.0015305,   0.001801,   0.0020025,   0.002204,   0.0022995,
-     0.002395,   0.0024735,   0.002552,   0.002512,   0.002472,   0.0026895,
-     0.002907,   0.003455,   0.004003,   0.0052815,   0.00656,   0.00985,
-     0.01314,   0.02076,   0.02838,   0.04826,   0.06814,   0.11167,
-     0.1552,   0.2164,   0.2776,   0.35445,   0.4313,   0.5306,
-     0.6299,   0.677,   0.7241,   0.75775,   0.7914,   0.81765,
-     0.8439,   0.86675,   0.8896,   0.9037,   0.9178,   0.92355,
-     0.9293,   0.94475,   0.9602,   0.9801,   1,   0.9958,
-     0.9916,   0.95475,   0.9179,   0.84515,   0.7724,   0.6729,
-     0.5734,   0.4787,   0.384,   0.32465,   0.2653,   0.21225,
-     0.1592,   0.120415,   0.08163,   0.075435,   0.06924,   0.06627,
-     0.0633,   0.055115,   0.04693,   0.03814,   0.02935,   0.023495,
-     0.01764,   0.015185,   0.01273,   0.012595,   0.01246,   0.012675,
-     0.01289,   0.012755,   0.01262,   0.011865,   0.01111,   0.0106,
-     0.01009,   0.0098255,   0.009561,   0.0094225,   0.009284,   0.0095255,
-     0.009767,   0.0102035,   0.01064,   0.010515,   0.01039,   0.0091415,
-     0.007893,   0.006632,   0.005371,   0.004464,   0.003557,   0.0030945,
-     0.002632,   0.0025675,   0.002503,   0.0024945,   0.002486,   0.0025155,
-     0.002545,   0.002665,   0.002785,   0.0027235,   0.002662,   0.0027025,
-     0.002743,   0.0030155,   0.003288,   0.003867,   0.004446,   0.006651,
-     0.008856,   0.012518,   0.01618,   0.020175,   0.02417,   0.02563,
-     0.02709,   0.02308,   0.01907,   0.0136865,   0.008303,   0.006957,
-     0.005611,   0.0063045,   0.006998,   0.008584,   0.01017,   0.011135,
-     0.0121,   0.0106205,   0.009141,   0.006401,   0.003661,   0.003178,
-     0.002695,   0.002812,   0.002929,   0.0027945,   0.00266,   0.002858,
-     0.003056,   0.0031515,   0.003247,   0.0034115,   0.003576,   0.003427,
-     0.003278,   0.0034455,   0.003613,   0.0036285,   0.003644,   0.003367,
-     0.00309,   0.003232,   0.003374,   0.003267,   0.00316,   0.0031495,
-     0.003139,   0.003062,   0.002985,   0.003139,   0.003293,   0.0033135,
-     0.003334,   0.00345,   0.003566,   0.003647,   0.003728,   0.003857,
-     0.003986,   0.0040515,   0.004117,   0.004197,   0.004277,   0.004226,
-     0.004175,   0.0045645,   0.004954,   0.0048685,   0.004783,   0.005318,
-     0.005853,   0.005788,   0.005723,   0.00567,   0.005617,   0.00546,
-     0.005303,   0.005252,   0.005201,   0.005183,   0.005165,   0.0051595,
-     0.005154,   0.0052175,   0.005281,   0.00549,   0.005699,   0.0062505,
-     0.006802,   0.007529,   0.008256,   0.0090055,   0.009755,   0.0101475,
-     0.01054,   0.010745,   0.01095,   0.010137,   0.009324,   0.0084725,
-     0.007621,   0.0068735,   0.006126,   0.0055815,   0.005037,   0.0046315,
-     0.004226,   0.003881,   0.003536,   0.0032265,   0.002917,   0.002516,
-     0.002115,   0.0019205,   0.001726,   0.001647,   0.001568,   0.0014765,
-     0.001385,   0.001294,   0.001203,   0.001205,   0.001207,   0.0012145,
-     0.001222,   0.0011705,   0.001119,   0.0011195,   0.00112,   0.001082,
-     0.001044,   0.0010645,   0.001085,   0.001156,   0.001227,   0.001233,
-     0.001239,   0.00135,   0.001461,   0.001648,   0.001835,   0.001667,
-     0.001499,   0.001511,   0.001523,   0.0014645,   0.001406,   0.0013125,
-     0.001219,   0.0006095,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0
+     0.0f,   4.816e-11f,   9.632e-11f,   1.4606e-10f,   1.958e-10f,   2.4715e-10f,
+     2.985e-10f,   3.514e-10f,   4.043e-10f,   0.000505f,   0.00101f,   0.0015305f,
+     0.002051f,   0.002587f,   0.003123f,   0.0036745f,   0.004226f,   0.0043815f,
+     0.004537f,   0.0049295f,   0.005322f,   0.0046895f,   0.004057f,   0.003661f,
+     0.003265f,   0.002984f,   0.002703f,   0.002503f,   0.002303f,   0.0017815f,
+     0.00126f,   0.0015305f,   0.001801f,   0.0020025f,   0.002204f,   0.0022995f,
+     0.002395f,   0.0024735f,   0.002552f,   0.002512f,   0.002472f,   0.0026895f,
+     0.002907f,   0.003455f,   0.004003f,   0.0052815f,   0.00656f,   0.00985f,
+     0.01314f,   0.02076f,   0.02838f,   0.04826f,   0.06814f,   0.11167f,
+     0.1552f,   0.2164f,   0.2776f,   0.35445f,   0.4313f,   0.5306f,
+     0.6299f,   0.677f,   0.7241f,   0.75775f,   0.7914f,   0.81765f,
+     0.8439f,   0.86675f,   0.8896f,   0.9037f,   0.9178f,   0.92355f,
+     0.9293f,   0.94475f,   0.9602f,   0.9801f,   1.0f,   0.9958f,
+     0.9916f,   0.95475f,   0.9179f,   0.84515f,   0.7724f,   0.6729f,
+     0.5734f,   0.4787f,   0.384f,   0.32465f,   0.2653f,   0.21225f,
+     0.1592f,   0.120415f,   0.08163f,   0.075435f,   0.06924f,   0.06627f,
+     0.0633f,   0.055115f,   0.04693f,   0.03814f,   0.02935f,   0.023495f,
+     0.01764f,   0.015185f,   0.01273f,   0.012595f,   0.01246f,   0.012675f,
+     0.01289f,   0.012755f,   0.01262f,   0.011865f,   0.01111f,   0.0106f,
+     0.01009f,   0.0098255f,   0.009561f,   0.0094225f,   0.009284f,   0.0095255f,
+     0.009767f,   0.0102035f,   0.01064f,   0.010515f,   0.01039f,   0.0091415f,
+     0.007893f,   0.006632f,   0.005371f,   0.004464f,   0.003557f,   0.0030945f,
+     0.002632f,   0.0025675f,   0.002503f,   0.0024945f,   0.002486f,   0.0025155f,
+     0.002545f,   0.002665f,   0.002785f,   0.0027235f,   0.002662f,   0.0027025f,
+     0.002743f,   0.0030155f,   0.003288f,   0.003867f,   0.004446f,   0.006651f,
+     0.008856f,   0.012518f,   0.01618f,   0.020175f,   0.02417f,   0.02563f,
+     0.02709f,   0.02308f,   0.01907f,   0.0136865f,   0.008303f,   0.006957f,
+     0.005611f,   0.0063045f,   0.006998f,   0.008584f,   0.01017f,   0.011135f,
+     0.0121f,   0.0106205f,   0.009141f,   0.006401f,   0.003661f,   0.003178f,
+     0.002695f,   0.002812f,   0.002929f,   0.0027945f,   0.00266f,   0.002858f,
+     0.003056f,   0.0031515f,   0.003247f,   0.0034115f,   0.003576f,   0.003427f,
+     0.003278f,   0.0034455f,   0.003613f,   0.0036285f,   0.003644f,   0.003367f,
+     0.00309f,   0.003232f,   0.003374f,   0.003267f,   0.00316f,   0.0031495f,
+     0.003139f,   0.003062f,   0.002985f,   0.003139f,   0.003293f,   0.0033135f,
+     0.003334f,   0.00345f,   0.003566f,   0.003647f,   0.003728f,   0.003857f,
+     0.003986f,   0.0040515f,   0.004117f,   0.004197f,   0.004277f,   0.004226f,
+     0.004175f,   0.0045645f,   0.004954f,   0.0048685f,   0.004783f,   0.005318f,
+     0.005853f,   0.005788f,   0.005723f,   0.00567f,   0.005617f,   0.00546f,
+     0.005303f,   0.005252f,   0.005201f,   0.005183f,   0.005165f,   0.0051595f,
+     0.005154f,   0.0052175f,   0.005281f,   0.00549f,   0.005699f,   0.0062505f,
+     0.006802f,   0.007529f,   0.008256f,   0.0090055f,   0.009755f,   0.0101475f,
+     0.01054f,   0.010745f,   0.01095f,   0.010137f,   0.009324f,   0.0084725f,
+     0.007621f,   0.0068735f,   0.006126f,   0.0055815f,   0.005037f,   0.0046315f,
+     0.004226f,   0.003881f,   0.003536f,   0.0032265f,   0.002917f,   0.002516f,
+     0.002115f,   0.0019205f,   0.001726f,   0.001647f,   0.001568f,   0.0014765f,
+     0.001385f,   0.001294f,   0.001203f,   0.001205f,   0.001207f,   0.0012145f,
+     0.001222f,   0.0011705f,   0.001119f,   0.0011195f,   0.00112f,   0.001082f,
+     0.001044f,   0.0010645f,   0.001085f,   0.001156f,   0.001227f,   0.001233f,
+     0.001239f,   0.00135f,   0.001461f,   0.001648f,   0.001835f,   0.001667f,
+     0.001499f,   0.001511f,   0.001523f,   0.0014645f,   0.001406f,   0.0013125f,
+     0.001219f,   0.0006095f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0
     };
 
     const float b2[321] =
     {
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0.001543,   0.003086,   0.0035565,   0.004027,   0.0031075,
-     0.002188,   0.0022535,   0.002319,   0.001899,   0.001479,   0.0014535,
-     0.001428,   0.00112715,   0.0008263,   0.00098315,   0.00114,   0.001191,
-     0.001242,   0.0011965,   0.001151,   0.001195,   0.001239,   0.00119,
-     0.001141,   0.001164,   0.001187,   0.001289,   0.001391,   0.0016425,
-     0.001894,   0.0021145,   0.002335,   0.002574,   0.002813,   0.0032595,
-     0.003706,   0.0046255,   0.005545,   0.0076825,   0.00982,   0.013835,
-     0.01785,   0.02064,   0.02343,   0.026765,   0.0301,   0.03563,
-     0.04116,   0.050415,   0.05967,   0.078915,   0.09816,   0.12738,
-     0.1566,   0.1924,   0.2282,   0.2739,   0.3196,   0.36855,
-     0.4175,   0.4726,   0.5277,   0.5928,   0.6579,   0.71385,
-     0.7698,   0.8005,   0.8312,   0.83785,   0.8445,   0.8575,
-     0.8705,   0.88935,   0.9082,   0.9271,   0.946,   0.96395,
-     0.9819,   0.99095,   1,   0.9967,   0.9934,   0.9876,
-     0.9818,   0.97545,   0.9691,   0.97325,   0.9774,   0.98215,
-     0.9869,   0.97605,   0.9652,   0.93155,   0.8979,   0.84445,
-     0.791,   0.72305,   0.6551,   0.56865,   0.4822,   0.3973,
-     0.3124,   0.25785,   0.2033,   0.17055,   0.1378,   0.11394,
-     0.09008,   0.072895,   0.05571,   0.046095,   0.03648,   0.032155,
-     0.02783,   0.026995,   0.02616,   0.02677,   0.02738,   0.02745,
-     0.02752,   0.02585,   0.02418,   0.02138,   0.01858,   0.016675,
-     0.01477,   0.01398,   0.01319,   0.013215,   0.01324,   0.01321,
-     0.01318,   0.01241,   0.01164,   0.0103975,   0.009155,   0.0076035,
-     0.006052,   0.005198,   0.004344,   0.003775,   0.003206,   0.0030305,
-     0.002855,   0.002863,   0.002871,   0.0034605,   0.00405,   0.0051125,
-     0.006175,   0.006901,   0.007627,   0.007632,   0.007637,   0.006665,
-     0.005693,   0.004709,   0.003725,   0.003184,   0.002643,   0.002404,
-     0.002165,   0.002389,   0.002613,   0.0028265,   0.00304,   0.0029335,
-     0.002827,   0.0029585,   0.00309,   0.003231,   0.003372,   0.0036625,
-     0.003953,   0.003888,   0.003823,   0.004107,   0.004391,   0.004264,
-     0.004137,   0.003973,   0.003809,   0.003648,   0.003487,   0.003354,
-     0.003221,   0.0031325,   0.003044,   0.0030325,   0.003021,   0.0030705,
-     0.00312,   0.0031665,   0.003213,   0.0032575,   0.003302,   0.0035005,
-     0.003699,   0.0040635,   0.004428,   0.004754,   0.00508,   0.0059895,
-     0.006899,   0.0073485,   0.007798,   0.008437,   0.009076,   0.0091385,
-     0.009201,   0.0091225,   0.009044,   0.0088315,   0.008619,   0.0082995,
-     0.00798,   0.00779,   0.0076,   0.007548,   0.007496,   0.007548,
-     0.0076,   0.007711,   0.007822,   0.0079615,   0.008101,   0.008127,
-     0.008153,   0.007961,   0.007769,   0.007238,   0.006707,   0.0061495,
-     0.005592,   0.005117,   0.004642,   0.0042505,   0.003859,   0.0034755,
-     0.003092,   0.00288,   0.002668,   0.0023465,   0.002025,   0.0018485,
-     0.001672,   0.001577,   0.001482,   0.001362,   0.001242,   0.001247,
-     0.001252,   0.001152,   0.001052,   0.00099725,   0.0009425,   0.0009543,
-     0.0009661,   0.00091635,   0.0008666,   0.0008281,   0.0007896,   0.00083065,
-     0.0008717,   0.00088005,   0.0008884,   0.00092515,   0.0009619,   0.00103995,
-     0.001118,   0.001196,   0.001274,   0.0011625,   0.001051,   0.0010565,
-     0.001062,   0.00096085,   0.0008597,   0.00091815,   0.0009766,   0.0009189,
-     0.0008612,   0.0004306,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.001543f,   0.003086f,   0.0035565f,   0.004027f,   0.0031075f,
+     0.002188f,   0.0022535f,   0.002319f,   0.001899f,   0.001479f,   0.0014535f,
+     0.001428f,   0.00112715f,   0.0008263f,   0.00098315f,   0.00114f,   0.001191f,
+     0.001242f,   0.0011965f,   0.001151f,   0.001195f,   0.001239f,   0.00119f,
+     0.001141f,   0.001164f,   0.001187f,   0.001289f,   0.001391f,   0.0016425f,
+     0.001894f,   0.0021145f,   0.002335f,   0.002574f,   0.002813f,   0.0032595f,
+     0.003706f,   0.0046255f,   0.005545f,   0.0076825f,   0.00982f,   0.013835f,
+     0.01785f,   0.02064f,   0.02343f,   0.026765f,   0.0301f,   0.03563f,
+     0.04116f,   0.050415f,   0.05967f,   0.078915f,   0.09816f,   0.12738f,
+     0.1566f,   0.1924f,   0.2282f,   0.2739f,   0.3196f,   0.36855f,
+     0.4175f,   0.4726f,   0.5277f,   0.5928f,   0.6579f,   0.71385f,
+     0.7698f,   0.8005f,   0.8312f,   0.83785f,   0.8445f,   0.8575f,
+     0.8705f,   0.88935f,   0.9082f,   0.9271f,   0.946f,   0.96395f,
+     0.9819f,   0.99095f,   1.0f,   0.9967f,   0.9934f,   0.9876f,
+     0.9818f,   0.97545f,   0.9691f,   0.97325f,   0.9774f,   0.98215f,
+     0.9869f,   0.97605f,   0.9652f,   0.93155f,   0.8979f,   0.84445f,
+     0.791f,   0.72305f,   0.6551f,   0.56865f,   0.4822f,   0.3973f,
+     0.3124f,   0.25785f,   0.2033f,   0.17055f,   0.1378f,   0.11394f,
+     0.09008f,   0.072895f,   0.05571f,   0.046095f,   0.03648f,   0.032155f,
+     0.02783f,   0.026995f,   0.02616f,   0.02677f,   0.02738f,   0.02745f,
+     0.02752f,   0.02585f,   0.02418f,   0.02138f,   0.01858f,   0.016675f,
+     0.01477f,   0.01398f,   0.01319f,   0.013215f,   0.01324f,   0.01321f,
+     0.01318f,   0.01241f,   0.01164f,   0.0103975f,   0.009155f,   0.0076035f,
+     0.006052f,   0.005198f,   0.004344f,   0.003775f,   0.003206f,   0.0030305f,
+     0.002855f,   0.002863f,   0.002871f,   0.0034605f,   0.00405f,   0.0051125f,
+     0.006175f,   0.006901f,   0.007627f,   0.007632f,   0.007637f,   0.006665f,
+     0.005693f,   0.004709f,   0.003725f,   0.003184f,   0.002643f,   0.002404f,
+     0.002165f,   0.002389f,   0.002613f,   0.0028265f,   0.00304f,   0.0029335f,
+     0.002827f,   0.0029585f,   0.00309f,   0.003231f,   0.003372f,   0.0036625f,
+     0.003953f,   0.003888f,   0.003823f,   0.004107f,   0.004391f,   0.004264f,
+     0.004137f,   0.003973f,   0.003809f,   0.003648f,   0.003487f,   0.003354f,
+     0.003221f,   0.0031325f,   0.003044f,   0.0030325f,   0.003021f,   0.0030705f,
+     0.00312f,   0.0031665f,   0.003213f,   0.0032575f,   0.003302f,   0.0035005f,
+     0.003699f,   0.0040635f,   0.004428f,   0.004754f,   0.00508f,   0.0059895f,
+     0.006899f,   0.0073485f,   0.007798f,   0.008437f,   0.009076f,   0.0091385f,
+     0.009201f,   0.0091225f,   0.009044f,   0.0088315f,   0.008619f,   0.0082995f,
+     0.00798f,   0.00779f,   0.0076f,   0.007548f,   0.007496f,   0.007548f,
+     0.0076f,   0.007711f,   0.007822f,   0.0079615f,   0.008101f,   0.008127f,
+     0.008153f,   0.007961f,   0.007769f,   0.007238f,   0.006707f,   0.0061495f,
+     0.005592f,   0.005117f,   0.004642f,   0.0042505f,   0.003859f,   0.0034755f,
+     0.003092f,   0.00288f,   0.002668f,   0.0023465f,   0.002025f,   0.0018485f,
+     0.001672f,   0.001577f,   0.001482f,   0.001362f,   0.001242f,   0.001247f,
+     0.001252f,   0.001152f,   0.001052f,   0.00099725f,   0.0009425f,   0.0009543f,
+     0.0009661f,   0.00091635f,   0.0008666f,   0.0008281f,   0.0007896f,   0.00083065f,
+     0.0008717f,   0.00088005f,   0.0008884f,   0.00092515f,   0.0009619f,   0.00103995f,
+     0.001118f,   0.001196f,   0.001274f,   0.0011625f,   0.001051f,   0.0010565f,
+     0.001062f,   0.00096085f,   0.0008597f,   0.00091815f,   0.0009766f,   0.0009189f,
+     0.0008612f,   0.0004306f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,
     };
 
     const float b3[321] =
     {
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0.0018575,   0.003715,   0.003079,   0.002443,   0.0020455,
-     0.001648,   0.0017865,   0.001925,   0.001553,   0.001181,   0.001127,
-     0.001073,   0.0009881,   0.0009032,   0.00093675,   0.0009703,   0.00094635,
-     0.0009224,   0.0011177,   0.001313,   0.000995,   0.000677,   0.0009465,
-     0.001216,   0.0012365,   0.001257,   0.001289,   0.001321,   0.0012365,
-     0.001152,   0.00107375,   0.0009955,   0.00125725,   0.001519,   0.001803,
-     0.002087,   0.002445,   0.002803,   0.0029485,   0.003094,   0.002991,
-     0.002888,   0.0028545,   0.002821,   0.002901,   0.002981,   0.0032205,
-     0.00346,   0.003574,   0.003688,   0.003422,   0.003156,   0.0026165,
-     0.002077,   0.002126,   0.002175,   0.0022785,   0.002382,   0.002534,
-     0.002686,   0.0028785,   0.003071,   0.003181,   0.003291,   0.0033965,
-     0.003502,   0.003615,   0.003728,   0.004149,   0.00457,   0.00494,
-     0.00531,   0.00563,   0.00595,   0.0061365,   0.006323,   0.006458,
-     0.006593,   0.0067545,   0.006916,   0.007343,   0.00777,   0.008377,
-     0.008984,   0.009607,   0.01023,   0.01101,   0.01179,   0.01283,
-     0.01387,   0.015775,   0.01768,   0.020725,   0.02377,   0.028595,
-     0.03342,   0.03993,   0.04644,   0.054755,   0.06307,   0.07513,
-     0.08719,   0.107645,   0.1281,   0.16655,   0.205,   0.26755,
-     0.3301,   0.41305,   0.496,   0.579,   0.662,   0.7337,
-     0.8054,   0.8447,   0.884,   0.8976,   0.9112,   0.9265,
-     0.9418,   0.9608,   0.9798,   0.9878,   0.9958,   0.9979,
-     1,   0.99615,   0.9923,   0.97235,   0.9524,   0.9125,
-     0.8726,   0.8128,   0.753,   0.6767,   0.6004,   0.51195,
-     0.4235,   0.35205,   0.2806,   0.22285,   0.1651,   0.130405,
-     0.09571,   0.07443,   0.05315,   0.041695,   0.03024,   0.026095,
-     0.02195,   0.021015,   0.02008,   0.020405,   0.02073,   0.021105,
-     0.02148,   0.02055,   0.01962,   0.01719,   0.01476,   0.0121415,
-     0.009523,   0.0080775,   0.006632,   0.0058285,   0.005025,   0.004769,
-     0.004513,   0.004338,   0.004163,   0.004345,   0.004527,   0.0047955,
-     0.005064,   0.005541,   0.006018,   0.0063415,   0.006665,   0.006433,
-     0.006201,   0.005328,   0.004455,   0.003759,   0.003063,   0.002884,
-     0.002705,   0.00257,   0.002435,   0.002453,   0.002471,   0.0024775,
-     0.002484,   0.0024255,   0.002367,   0.0024915,   0.002616,   0.00253,
-     0.002444,   0.002528,   0.002612,   0.0025575,   0.002503,   0.00255,
-     0.002597,   0.002551,   0.002505,   0.002426,   0.002347,   0.0023605,
-     0.002374,   0.0022935,   0.002213,   0.002167,   0.002121,   0.002053,
-     0.001985,   0.001928,   0.001871,   0.00194,   0.002009,   0.002071,
-     0.002133,   0.002293,   0.002453,   0.0026255,   0.002798,   0.0027925,
-     0.002787,   0.002651,   0.002515,   0.0020235,   0.001532,   0.001344,
-     0.001156,   0.001118,   0.00108,   0.0010297,   0.0009794,   0.0009771,
-     0.0009748,   0.0010049,   0.001035,   0.00092405,   0.0008131,   0.00082065,
-     0.0008282,   0.0007723,   0.0007164,   0.00070735,   0.0006983,   0.00070225,
-     0.0007062,   0.0006895,   0.0006728,   0.0006287,   0.0005846,   0.0006068,
-     0.000629,   0.00065395,   0.0006789,   0.00071925,   0.0007596,   0.000719,
-     0.0006784,   0.00066125,   0.0006441,   0.0007476,   0.0008511,   0.0008908,
-     0.0009305,   0.0008436,   0.0007567,   0.0007948,   0.0008329,   0.000872,
-     0.0009111,   0.00089545,   0.0008798,   0.0007618,   0.0006438,   0.00073805,
-     0.0008323,   0.00041615,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0018575f,   0.003715f,   0.003079f,   0.002443f,   0.0020455f,
+     0.001648f,   0.0017865f,   0.001925f,   0.001553f,   0.001181f,   0.001127f,
+     0.001073f,   0.0009881f,   0.0009032f,   0.00093675f,   0.0009703f,   0.00094635f,
+     0.0009224f,   0.0011177f,   0.001313f,   0.000995f,   0.000677f,   0.0009465f,
+     0.001216f,   0.0012365f,   0.001257f,   0.001289f,   0.001321f,   0.0012365f,
+     0.001152f,   0.00107375f,   0.0009955f,   0.00125725f,   0.001519f,   0.001803f,
+     0.002087f,   0.002445f,   0.002803f,   0.0029485f,   0.003094f,   0.002991f,
+     0.002888f,   0.0028545f,   0.002821f,   0.002901f,   0.002981f,   0.0032205f,
+     0.00346f,   0.003574f,   0.003688f,   0.003422f,   0.003156f,   0.0026165f,
+     0.002077f,   0.002126f,   0.002175f,   0.0022785f,   0.002382f,   0.002534f,
+     0.002686f,   0.0028785f,   0.003071f,   0.003181f,   0.003291f,   0.0033965f,
+     0.003502f,   0.003615f,   0.003728f,   0.004149f,   0.00457f,   0.00494f,
+     0.00531f,   0.00563f,   0.00595f,   0.0061365f,   0.006323f,   0.006458f,
+     0.006593f,   0.0067545f,   0.006916f,   0.007343f,   0.00777f,   0.008377f,
+     0.008984f,   0.009607f,   0.01023f,   0.01101f,   0.01179f,   0.01283f,
+     0.01387f,   0.015775f,   0.01768f,   0.020725f,   0.02377f,   0.028595f,
+     0.03342f,   0.03993f,   0.04644f,   0.054755f,   0.06307f,   0.07513f,
+     0.08719f,   0.107645f,   0.1281f,   0.16655f,   0.205f,   0.26755f,
+     0.3301f,   0.41305f,   0.496f,   0.579f,   0.662f,   0.7337f,
+     0.8054f,   0.8447f,   0.884f,   0.8976f,   0.9112f,   0.9265f,
+     0.9418f,   0.9608f,   0.9798f,   0.9878f,   0.9958f,   0.9979f,
+     1.0f,   0.99615f,   0.9923f,   0.97235f,   0.9524f,   0.9125f,
+     0.8726f,   0.8128f,   0.753f,   0.6767f,   0.6004f,   0.51195f,
+     0.4235f,   0.35205f,   0.2806f,   0.22285f,   0.1651f,   0.130405f,
+     0.09571f,   0.07443f,   0.05315f,   0.041695f,   0.03024f,   0.026095f,
+     0.02195f,   0.021015f,   0.02008f,   0.020405f,   0.02073f,   0.021105f,
+     0.02148f,   0.02055f,   0.01962f,   0.01719f,   0.01476f,   0.0121415f,
+     0.009523f,   0.0080775f,   0.006632f,   0.0058285f,   0.005025f,   0.004769f,
+     0.004513f,   0.004338f,   0.004163f,   0.004345f,   0.004527f,   0.0047955f,
+     0.005064f,   0.005541f,   0.006018f,   0.0063415f,   0.006665f,   0.006433f,
+     0.006201f,   0.005328f,   0.004455f,   0.003759f,   0.003063f,   0.002884f,
+     0.002705f,   0.00257f,   0.002435f,   0.002453f,   0.002471f,   0.0024775f,
+     0.002484f,   0.0024255f,   0.002367f,   0.0024915f,   0.002616f,   0.00253f,
+     0.002444f,   0.002528f,   0.002612f,   0.0025575f,   0.002503f,   0.00255f,
+     0.002597f,   0.002551f,   0.002505f,   0.002426f,   0.002347f,   0.0023605f,
+     0.002374f,   0.0022935f,   0.002213f,   0.002167f,   0.002121f,   0.002053f,
+     0.001985f,   0.001928f,   0.001871f,   0.00194f,   0.002009f,   0.002071f,
+     0.002133f,   0.002293f,   0.002453f,   0.0026255f,   0.002798f,   0.0027925f,
+     0.002787f,   0.002651f,   0.002515f,   0.0020235f,   0.001532f,   0.001344f,
+     0.001156f,   0.001118f,   0.00108f,   0.0010297f,   0.0009794f,   0.0009771f,
+     0.0009748f,   0.0010049f,   0.001035f,   0.00092405f,   0.0008131f,   0.00082065f,
+     0.0008282f,   0.0007723f,   0.0007164f,   0.00070735f,   0.0006983f,   0.00070225f,
+     0.0007062f,   0.0006895f,   0.0006728f,   0.0006287f,   0.0005846f,   0.0006068f,
+     0.000629f,   0.00065395f,   0.0006789f,   0.00071925f,   0.0007596f,   0.000719f,
+     0.0006784f,   0.00066125f,   0.0006441f,   0.0007476f,   0.0008511f,   0.0008908f,
+     0.0009305f,   0.0008436f,   0.0007567f,   0.0007948f,   0.0008329f,   0.000872f,
+     0.0009111f,   0.00089545f,   0.0008798f,   0.0007618f,   0.0006438f,   0.00073805f,
+     0.0008323f,   0.00041615f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f
     };
 
     const float b4[321] =
     {
-     0,   6.72e-11,   1.344e-10,   2.038e-10,   2.732e-10,   3.4475e-10,
-     4.163e-10,   4.901e-10,   5.639e-10,   0.0007045,   0.001409,   0.002135,
-     0.002861,   0.0036085,   0.004356,   0.0051255,   0.005895,   0.006112,
-     0.006329,   0.0061655,   0.006002,   0.005693,   0.005384,   0.0044505,
-     0.003517,   0.0028125,   0.002108,   0.002272,   0.002436,   0.002068,
-     0.0017,   0.0019855,   0.002271,   0.0020705,   0.00187,   0.0017455,
-     0.001621,   0.0017855,   0.00195,   0.0018905,   0.001831,   0.0016705,
-     0.00151,   0.0015045,   0.001499,   0.001721,   0.001943,   0.0018305,
-     0.001718,   0.002082,   0.002446,   0.002492,   0.002538,   0.002833,
-     0.003128,   0.003589,   0.00405,   0.0043915,   0.004733,   0.0047405,
-     0.004748,   0.004824,   0.0049,   0.004541,   0.004182,   0.004313,
-     0.004444,   0.0046115,   0.004779,   0.005007,   0.005235,   0.005396,
-     0.005557,   0.0054025,   0.005248,   0.0047195,   0.004191,   0.0035905,
-     0.00299,   0.0028175,   0.002645,   0.0026115,   0.002578,   0.002558,
-     0.002538,   0.0027,   0.002862,   0.002721,   0.00258,   0.002973,
-     0.003366,   0.004324,   0.005282,   0.006576,   0.00787,   0.008871,
-     0.009872,   0.010051,   0.01023,   0.0090465,   0.007863,   0.006367,
-     0.004871,   0.0048565,   0.004842,   0.0055935,   0.006345,   0.0069985,
-     0.007652,   0.0077885,   0.007925,   0.007197,   0.006469,   0.0054185,
-     0.004368,   0.004082,   0.003796,   0.003768,   0.00374,   0.0036695,
-     0.003599,   0.0036165,   0.003634,   0.0037785,   0.003923,   0.0042145,
-     0.004506,   0.004688,   0.00487,   0.0052705,   0.005671,   0.005878,
-     0.006085,   0.006441,   0.006797,   0.007044,   0.007291,   0.007926,
-     0.008561,   0.0092905,   0.01002,   0.010625,   0.01123,   0.01174,
-     0.01225,   0.012595,   0.01294,   0.01323,   0.01352,   0.01396,
-     0.0144,   0.01499,   0.01558,   0.01641,   0.01724,   0.01842,
-     0.0196,   0.021835,   0.02407,   0.026755,   0.02944,   0.03189,
-     0.03434,   0.03751,   0.04068,   0.04483,   0.04898,   0.05445,
-     0.05992,   0.066405,   0.07289,   0.081705,   0.09052,   0.10501,
-     0.1195,   0.141,   0.1625,   0.20245,   0.2424,   0.3015,
-     0.3606,   0.4268,   0.493,   0.564,   0.635,   0.71665,
-     0.7983,   0.8726,   0.9469,   0.97345,   1,   0.99855,
-     0.9971,   0.98365,   0.9702,   0.9526,   0.935,   0.91795,
-     0.9009,   0.88535,   0.8698,   0.86065,   0.8515,   0.84485,
-     0.8382,   0.8352,   0.8322,   0.8289,   0.8256,   0.823,
-     0.8204,   0.8137,   0.807,   0.7957,   0.7844,   0.76695,
-     0.7495,   0.72675,   0.704,   0.6911,   0.6782,   0.6638,
-     0.6494,   0.6313,   0.6132,   0.59005,   0.5669,   0.5493,
-     0.5317,   0.5117,   0.4917,   0.4644,   0.4371,   0.3943,
-     0.3515,   0.3134,   0.2753,   0.24845,   0.2216,   0.191,
-     0.1604,   0.1385,   0.1166,   0.1003,   0.084,   0.07559,
-     0.06718,   0.054015,   0.04085,   0.030665,   0.02048,   0.017005,
-     0.01353,   0.01178,   0.01003,   0.0089005,   0.007771,   0.007077,
-     0.006383,   0.0058745,   0.005366,   0.0049605,   0.004555,   0.0040195,
-     0.003484,   0.0031455,   0.002807,   0.002621,   0.002435,   0.0023315,
-     0.002228,   0.002158,   0.002088,   0.001973,   0.001858,   0.001839,
-     0.00182,   0.0018615,   0.001903,   0.001759,   0.001615,   0.0016735,
-     0.001732,   0.0017285,   0.001725,   0.001884,   0.002043,   0.0020925,
-     0.002142,   0.0020825,   0.002023,   0.001963,   0.001903,   0.0018045,
-     0.001706,   0.0017565,   0.001807,   0.0017525,   0.001698,   0.001849,
-     0.002,   0.001,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0,   0,   0,   0,
-     0,   0,   0
+     0.0f,   6.72e-11f,   1.344e-10f,   2.038e-10f,   2.732e-10f,   3.4475e-10f,
+     4.163e-10f,   4.901e-10f,   5.639e-10f,   0.0007045f,   0.001409f,   0.002135f,
+     0.002861f,   0.0036085f,   0.004356f,   0.0051255f,   0.005895f,   0.006112f,
+     0.006329f,   0.0061655f,   0.006002f,   0.005693f,   0.005384f,   0.0044505f,
+     0.003517f,   0.0028125f,   0.002108f,   0.002272f,   0.002436f,   0.002068f,
+     0.0017f,   0.0019855f,   0.002271f,   0.0020705f,   0.00187f,   0.0017455f,
+     0.001621f,   0.0017855f,   0.00195f,   0.0018905f,   0.001831f,   0.0016705f,
+     0.00151f,   0.0015045f,   0.001499f,   0.001721f,   0.001943f,   0.0018305f,
+     0.001718f,   0.002082f,   0.002446f,   0.002492f,   0.002538f,   0.002833f,
+     0.003128f,   0.003589f,   0.00405f,   0.0043915f,   0.004733f,   0.0047405f,
+     0.004748f,   0.004824f,   0.0049f,   0.004541f,   0.004182f,   0.004313f,
+     0.004444f,   0.0046115f,   0.004779f,   0.005007f,   0.005235f,   0.005396f,
+     0.005557f,   0.0054025f,   0.005248f,   0.0047195f,   0.004191f,   0.0035905f,
+     0.00299f,   0.0028175f,   0.002645f,   0.0026115f,   0.002578f,   0.002558f,
+     0.002538f,   0.0027f,   0.002862f,   0.002721f,   0.00258f,   0.002973f,
+     0.003366f,   0.004324f,   0.005282f,   0.006576f,   0.00787f,   0.008871f,
+     0.009872f,   0.010051f,   0.01023f,   0.0090465f,   0.007863f,   0.006367f,
+     0.004871f,   0.0048565f,   0.004842f,   0.0055935f,   0.006345f,   0.0069985f,
+     0.007652f,   0.0077885f,   0.007925f,   0.007197f,   0.006469f,   0.0054185f,
+     0.004368f,   0.004082f,   0.003796f,   0.003768f,   0.00374f,   0.0036695f,
+     0.003599f,   0.0036165f,   0.003634f,   0.0037785f,   0.003923f,   0.0042145f,
+     0.004506f,   0.004688f,   0.00487f,   0.0052705f,   0.005671f,   0.005878f,
+     0.006085f,   0.006441f,   0.006797f,   0.007044f,   0.007291f,   0.007926f,
+     0.008561f,   0.0092905f,   0.01002f,   0.010625f,   0.01123f,   0.01174f,
+     0.01225f,   0.012595f,   0.01294f,   0.01323f,   0.01352f,   0.01396f,
+     0.0144f,   0.01499f,   0.01558f,   0.01641f,   0.01724f,   0.01842f,
+     0.0196f,   0.021835f,   0.02407f,   0.026755f,   0.02944f,   0.03189f,
+     0.03434f,   0.03751f,   0.04068f,   0.04483f,   0.04898f,   0.05445f,
+     0.05992f,   0.066405f,   0.07289f,   0.081705f,   0.09052f,   0.10501f,
+     0.1195f,   0.141f,   0.1625f,   0.20245f,   0.2424f,   0.3015f,
+     0.3606f,   0.4268f,   0.493f,   0.564f,   0.635f,   0.71665f,
+     0.7983f,   0.8726f,   0.9469f,   0.97345f,   1.0f,   0.99855f,
+     0.9971f,   0.98365f,   0.9702f,   0.9526f,   0.935f,   0.91795f,
+     0.9009f,   0.88535f,   0.8698f,   0.86065f,   0.8515f,   0.84485f,
+     0.8382f,   0.8352f,   0.8322f,   0.8289f,   0.8256f,   0.823f,
+     0.8204f,   0.8137f,   0.807f,   0.7957f,   0.7844f,   0.76695f,
+     0.7495f,   0.72675f,   0.704f,   0.6911f,   0.6782f,   0.6638f,
+     0.6494f,   0.6313f,   0.6132f,   0.59005f,   0.5669f,   0.5493f,
+     0.5317f,   0.5117f,   0.4917f,   0.4644f,   0.4371f,   0.3943f,
+     0.3515f,   0.3134f,   0.2753f,   0.24845f,   0.2216f,   0.191f,
+     0.1604f,   0.1385f,   0.1166f,   0.1003f,   0.084f,   0.07559f,
+     0.06718f,   0.054015f,   0.04085f,   0.030665f,   0.02048f,   0.017005f,
+     0.01353f,   0.01178f,   0.01003f,   0.0089005f,   0.007771f,   0.007077f,
+     0.006383f,   0.0058745f,   0.005366f,   0.0049605f,   0.004555f,   0.0040195f,
+     0.003484f,   0.0031455f,   0.002807f,   0.002621f,   0.002435f,   0.0023315f,
+     0.002228f,   0.002158f,   0.002088f,   0.001973f,   0.001858f,   0.001839f,
+     0.00182f,   0.0018615f,   0.001903f,   0.001759f,   0.001615f,   0.0016735f,
+     0.001732f,   0.0017285f,   0.001725f,   0.001884f,   0.002043f,   0.0020925f,
+     0.002142f,   0.0020825f,   0.002023f,   0.001963f,   0.001903f,   0.0018045f,
+     0.001706f,   0.0017565f,   0.001807f,   0.0017525f,   0.001698f,   0.001849f,
+     0.002f,   0.001f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f,   0.0f,   0.0f,   0.0f,
+     0.0f,   0.0f,   0.0f
     };
     //Add multispectral bands to the temporary list
     const std::vector<float> vb1 (b1, b1 + sizeof(b1) / sizeof(float) );
