@@ -759,380 +759,379 @@ SpotImageMetadataInterface
     //FIXME add other instrument relative spectral response (not only HRG1)
     const float green[541] =
         {
-          0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0022771144,
-0.0045542287,0.021714223,0.038874217,0.088104725,0.13733523,0.21823871,
-0.29914218,0.38027802,0.46141386,0.52832052,0.59522718,0.64936955,
-0.70351192,0.74529693,0.78708195,0.82499008,0.86289822,0.891466,
-0.92003378,0.94254762,0.96506146,0.9776788,0.99029614,0.99514807,
-1.0,0.99612511,0.99225022,0.9804036,0.96855699,0.94715939,
-0.9257618,0.90154813,0.87733446,0.84871261,0.82009075,0.78645969,
-0.75282863,0.71875799,0.68468734,0.64818039,0.61167343,0.57338572,
-0.53509801,0.49156491,0.44803182,0.39732491,0.346618,0.29724838,
-0.24787875,0.20190886,0.15593897,0.12403284,0.09212672,0.070920769,
-0.049714818,0.03798244,0.026250061,0.019816831,0.013383602,0.010152718,
-0.006921834,0.0054235249,0.0039252158,0.0033455489,0.002765882,0.001382941,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0
-        };
+          0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0022771144f,
+0.0045542287f,0.021714223f,0.038874217f,0.088104725f,0.13733523f,0.21823871f,
+0.29914218f,0.38027802f,0.46141386f,0.52832052f,0.59522718f,0.64936955f,
+0.70351192f,0.74529693f,0.78708195f,0.82499008f,0.86289822f,0.891466f,
+0.92003378f,0.94254762f,0.96506146f,0.9776788f,0.99029614f,0.99514807f,
+1.0f,0.99612511f,0.99225022f,0.9804036f,0.96855699f,0.94715939f,
+0.9257618f,0.90154813f,0.87733446f,0.84871261f,0.82009075f,0.78645969f,
+0.75282863f,0.71875799f,0.68468734f,0.64818039f,0.61167343f,0.57338572f,
+0.53509801f,0.49156491f,0.44803182f,0.39732491f,0.346618f,0.29724838f,
+0.24787875f,0.20190886f,0.15593897f,0.12403284f,0.09212672f,0.070920769f,
+0.049714818f,0.03798244f,0.026250061f,0.019816831f,0.013383602f,0.010152718f,
+0.006921834f,0.0054235249f,0.0039252158f,0.0033455489f,0.002765882f,0.001382941f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f};
 
     const float red[541] =
         {
-          0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0007673711,
-0.0015347422,0.010419638,0.019304534,0.061542786,0.10378104,0.20079599,
-0.29781095,0.41207816,0.52634536,0.62039262,0.71443988,0.78093055,
-0.84742121,0.88691213,0.92640305,0.95094047,0.9754779,0.98546823,
-0.99545857,0.99772928,1.0,0.99374775,0.98749549,0.97497667,
-0.96245784,0.94318133,0.92390482,0.89924371,0.8745826,0.84464903,
-0.81471546,0.76863444,0.72255341,0.65866954,0.59478567,0.5169305,
-0.43907532,0.36620824,0.29334116,0.23579319,0.17824522,0.14140026,
-0.1045553,0.082135956,0.059716612,0.047238187,0.034759762,0.027242624,
-0.019725486,0.015547759,0.011370033,0.0090187963,0.0066675595,0.0050977127,
-0.0035278658,0.0028316045,0.0021353432,0.0010676716,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0
+          0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0007673711f,
+0.0015347422f,0.010419638f,0.019304534f,0.061542786f,0.10378104f,0.20079599f,
+0.29781095f,0.41207816f,0.52634536f,0.62039262f,0.71443988f,0.78093055f,
+0.84742121f,0.88691213f,0.92640305f,0.95094047f,0.9754779f,0.98546823f,
+0.99545857f,0.99772928f,1.0f,0.99374775f,0.98749549f,0.97497667f,
+0.96245784f,0.94318133f,0.92390482f,0.89924371f,0.8745826f,0.84464903f,
+0.81471546f,0.76863444f,0.72255341f,0.65866954f,0.59478567f,0.5169305f,
+0.43907532f,0.36620824f,0.29334116f,0.23579319f,0.17824522f,0.14140026f,
+0.1045553f,0.082135956f,0.059716612f,0.047238187f,0.034759762f,0.027242624f,
+0.019725486f,0.015547759f,0.011370033f,0.0090187963f,0.0066675595f,0.0050977127f,
+0.0035278658f,0.0028316045f,0.0021353432f,0.0010676716f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f
         };
     const float nir[541] =
         {
-          0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.00046485267,
-0.00092970533,0.0022703511,0.0036109969,0.0072833599,0.010955723,0.020381246,
-0.029806769,0.050425041,0.071043314,0.10698612,0.14292892,0.19323862,
-0.24354832,0.30664343,0.36973854,0.43590247,0.5020664,0.56601537,
-0.62996434,0.68195348,0.73394262,0.77728387,0.82062512,0.85237025,
-0.88411539,0.91130117,0.93848695,0.95316338,0.96783982,0.9764626,
-0.98508538,0.99215522,0.99922506,0.99961253,1.0,0.99705423,
-0.99410845,0.98330518,0.97250191,0.95825152,0.94400112,0.93075194,
-0.91750276,0.90228886,0.88707495,0.87152458,0.8559742,0.82966368,
-0.80335316,0.7684215,0.73348985,0.68197206,0.63045427,0.56244955,
-0.49444484,0.43235415,0.37026347,0.30941829,0.24857311,0.20286212,
-0.15715112,0.13022816,0.1033052,0.084892217,0.06647923,0.053553967,
-0.040628703,0.03389025,0.027151797,0.022906605,0.018661412,0.015551925,
-0.012442438,0.010396472,0.0083505073,0.0070520644,0.0057536215,0.0049600816,
-0.0041665416,0.0035720051,0.0029774686,0.0029639347,0.0029504007,0.0029368668,
-0.0029233328,0.0029097989,0.0028962649,0.002882731,0.0028691971,0.0028556631,
-0.0028421292,0.0028285952,0.0028150613,0.0028015273,0.0027879934,0.0027744594,
-0.0027609255,0.0027473915,0.0027338576,0.0027203236,0.0027067897,0.0026932557,
-0.0026797218,0.0026661878,0.0026526539,0.0026391199,0.002625586,0.002612052,
-0.0025985181,0.0025849841,0.0025714502,0.0025579162,0.0025443823,0.0025308483,
-0.0025173144,0.0025037804,0.0024902465,0.0024767125,0.0024631786,0.0024496447,
-0.0024361107,0.0024225768,0.0024090428,0.0023955089,0.0023819749,0.002368441,
-0.002354907,0.0023413731,0.0023278391,0.0023143052,0.0023007712,0.0022872373,
-0.0022737033,0.0022601694,0.0022466354,0.0022331015,0.0022195675,0.0022060336,
-0.0021924996,0.0021789657,0.0021654317,0.0021518978,0.0021383638,0.0021248299,
-0.0021112959,0.002097762,0.002084228,0.0020706941,0.0020571601,0.0020436262,
-0.0020300923,0.0020165583,0.0020030244,0.0019894904,0.0019759565,0.0019624225,
-0.0019488886,0.0019353546,0.0019218207,0.0019082867,0.0018947528,0.0018812188,
-0.0018676849,0.0018541509,0.001840617,0.001827083,0.0018135491,0.0018000151,
-0.0017864812,0.0017729472,0.0017594133,0.0017458793,0.0017323454,0.0017188114,
-0.0017052775,0.0016917435,0.0016782096,0.0016646756,0.0016511417,0.0016376078,
-0.0016240738,0.0016105399,0.0015970059,0.001583472,0.001569938,0.0015564041,
-0.0015428701,0.0015293362,0.0015158022,0.0015022683,0.0014887343,0.0014752004,
-0.0014616664,0.0014481325,0.0014345985,0.0014210646,0.0014075306,0.0013939967,
-0.0013804627,0.0013669288,0.0013533948,0.0013398609,0.0013263269,0.001312793,
-0.001299259,0.0012857251,0.0012721911,0.0012586572,0.0012451232,0.0012315893,
-0.0012180554,0.0012045214,0.0011909875,0.0011774535,0.0011639196,0.0011503856,
-0.0011368517,0.0011233177,0.0011097838,0.0010962498,0.0010827159,0.0010691819,
-0.001055648,0.001042114,0.0010285801,0.0010150461,0.0010015122,0.00098797823,
-0.00097444428,0.00096091033,0.00094737638,0.00093384244,0.00092030849,0.00090677454,
-0.00089324059,0.00087970664,0.00086617269,0.00085263875,0.0008391048,0.00082557085,
-0.0008120369,0.00079850295,0.000784969,0.00077143506,0.00075790111,0.00074436716,
-0.00073083321,0.00071729926,0.00070376531,0.00069023137,0.00067669742,0.00066316347,
-0.00064962952,0.00063609557,0.00062256162,0.00060902768,0.00059549373,0.00058195978,
-0.00056842583,0.00055489188,0.00054135793,0.00052782399,0.00051429004,0.00050075609,
-0.00048722214,0.00047368819,0.00046015424,0.0004466203,0.00043308635,0.0004195524,
-0.00040601845,0.0003924845,0.00037895055,0.00036541661,0.00035188266,0.00033834871,
-0.00032481476,0.00031128081,0.00029774686,0.00028421292,0.00027067897,0.00025714502,
-0.00024361107,0.00023007712,0.00021654317,0.00020300923,0.00018947528,0.00017594133,
-0.00016240738,0.00014887343,0.00013533948,0.00012180554,0.00010827159,9.4737638e-05,
-8.120369e-05,6.7669742e-05,5.4135793e-05,4.0601845e-05,2.7067897e-05,1.3533948e-05,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0
+          0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.00046485267f,
+0.00092970533f,0.0022703511f,0.0036109969f,0.0072833599f,0.010955723f,0.020381246f,
+0.029806769f,0.050425041f,0.071043314f,0.10698612f,0.14292892f,0.19323862f,
+0.24354832f,0.30664343f,0.36973854f,0.43590247f,0.5020664f,0.56601537f,
+0.62996434f,0.68195348f,0.73394262f,0.77728387f,0.82062512f,0.85237025f,
+0.88411539f,0.91130117f,0.93848695f,0.95316338f,0.96783982f,0.9764626f,
+0.98508538f,0.99215522f,0.99922506f,0.99961253f,1.0f,0.99705423f,
+0.99410845f,0.98330518f,0.97250191f,0.95825152f,0.94400112f,0.93075194f,
+0.91750276f,0.90228886f,0.88707495f,0.87152458f,0.8559742f,0.82966368f,
+0.80335316f,0.7684215f,0.73348985f,0.68197206f,0.63045427f,0.56244955f,
+0.49444484f,0.43235415f,0.37026347f,0.30941829f,0.24857311f,0.20286212f,
+0.15715112f,0.13022816f,0.1033052f,0.084892217f,0.06647923f,0.053553967f,
+0.040628703f,0.03389025f,0.027151797f,0.022906605f,0.018661412f,0.015551925f,
+0.012442438f,0.010396472f,0.0083505073f,0.0070520644f,0.0057536215f,0.0049600816f,
+0.0041665416f,0.0035720051f,0.0029774686f,0.0029639347f,0.0029504007f,0.0029368668f,
+0.0029233328f,0.0029097989f,0.0028962649f,0.002882731f,0.0028691971f,0.0028556631f,
+0.0028421292f,0.0028285952f,0.0028150613f,0.0028015273f,0.0027879934f,0.0027744594f,
+0.0027609255f,0.0027473915f,0.0027338576f,0.0027203236f,0.0027067897f,0.0026932557f,
+0.0026797218f,0.0026661878f,0.0026526539f,0.0026391199f,0.002625586f,0.002612052f,
+0.0025985181f,0.0025849841f,0.0025714502f,0.0025579162f,0.0025443823f,0.0025308483f,
+0.0025173144f,0.0025037804f,0.0024902465f,0.0024767125f,0.0024631786f,0.0024496447f,
+0.0024361107f,0.0024225768f,0.0024090428f,0.0023955089f,0.0023819749f,0.002368441f,
+0.002354907f,0.0023413731f,0.0023278391f,0.0023143052f,0.0023007712f,0.0022872373f,
+0.0022737033f,0.0022601694f,0.0022466354f,0.0022331015f,0.0022195675f,0.0022060336f,
+0.0021924996f,0.0021789657f,0.0021654317f,0.0021518978f,0.0021383638f,0.0021248299f,
+0.0021112959f,0.002097762f,0.002084228f,0.0020706941f,0.0020571601f,0.0020436262f,
+0.0020300923f,0.0020165583f,0.0020030244f,0.0019894904f,0.0019759565f,0.0019624225f,
+0.0019488886f,0.0019353546f,0.0019218207f,0.0019082867f,0.0018947528f,0.0018812188f,
+0.0018676849f,0.0018541509f,0.001840617f,0.001827083f,0.0018135491f,0.0018000151f,
+0.0017864812f,0.0017729472f,0.0017594133f,0.0017458793f,0.0017323454f,0.0017188114f,
+0.0017052775f,0.0016917435f,0.0016782096f,0.0016646756f,0.0016511417f,0.0016376078f,
+0.0016240738f,0.0016105399f,0.0015970059f,0.001583472f,0.001569938f,0.0015564041f,
+0.0015428701f,0.0015293362f,0.0015158022f,0.0015022683f,0.0014887343f,0.0014752004f,
+0.0014616664f,0.0014481325f,0.0014345985f,0.0014210646f,0.0014075306f,0.0013939967f,
+0.0013804627f,0.0013669288f,0.0013533948f,0.0013398609f,0.0013263269f,0.001312793f,
+0.001299259f,0.0012857251f,0.0012721911f,0.0012586572f,0.0012451232f,0.0012315893f,
+0.0012180554f,0.0012045214f,0.0011909875f,0.0011774535f,0.0011639196f,0.0011503856f,
+0.0011368517f,0.0011233177f,0.0011097838f,0.0010962498f,0.0010827159f,0.0010691819f,
+0.001055648f,0.001042114f,0.0010285801f,0.0010150461f,0.0010015122f,0.00098797823f,
+0.00097444428f,0.00096091033f,0.00094737638f,0.00093384244f,0.00092030849f,0.00090677454f,
+0.00089324059f,0.00087970664f,0.00086617269f,0.00085263875f,0.0008391048f,0.00082557085f,
+0.0008120369f,0.00079850295f,0.000784969f,0.00077143506f,0.00075790111f,0.00074436716f,
+0.00073083321f,0.00071729926f,0.00070376531f,0.00069023137f,0.00067669742f,0.00066316347f,
+0.00064962952f,0.00063609557f,0.00062256162f,0.00060902768f,0.00059549373f,0.00058195978f,
+0.00056842583f,0.00055489188f,0.00054135793f,0.00052782399f,0.00051429004f,0.00050075609f,
+0.00048722214f,0.00047368819f,0.00046015424f,0.0004466203f,0.00043308635f,0.0004195524f,
+0.00040601845f,0.0003924845f,0.00037895055f,0.00036541661f,0.00035188266f,0.00033834871f,
+0.00032481476f,0.00031128081f,0.00029774686f,0.00028421292f,0.00027067897f,0.00025714502f,
+0.00024361107f,0.00023007712f,0.00021654317f,0.00020300923f,0.00018947528f,0.00017594133f,
+0.00016240738f,0.00014887343f,0.00013533948f,0.00012180554f,0.00010827159f,9.4737638e-05f,
+8.120369e-05f,6.7669742e-05f,5.4135793e-05f,4.0601845e-05f,2.7067897e-05f,1.3533948e-05f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f
         };
     const float mir[541] =
         {
-          0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0,0.0,0.0,0.0,0.0,
-0.0,0.0088105211,0.017621042,0.020528086,0.02343513,0.026392526,
-0.029349921,0.033664215,0.037978508,0.042245031,0.046511554,0.055648902,
-0.064786249,0.07395196,0.08311767,0.10386151,0.12460535,0.14594447,
-0.16728359,0.20442288,0.24156217,0.27841272,0.31526328,0.35919335,
-0.40312341,0.44621342,0.48930344,0.53207715,0.57485086,0.61905294,
-0.66325502,0.7114532,0.75965137,0.8076253,0.85559924,0.89376042,
-0.93192161,0.9659608,1.0,0.99696894,0.99393787,0.99224825,
-0.99055862,0.96192825,0.93329788,0.90629723,0.87929659,0.87156435,
-0.8638321,0.85303543,0.84223875,0.85502674,0.86781473,0.88056734,
-0.89331995,0.89301593,0.89271191,0.86628263,0.83985335,0.80572933,
-0.77160531,0.73099612,0.69038694,0.64866608,0.60694523,0.56782227,
-0.52869932,0.48719362,0.44568791,0.40599882,0.36630972,0.32807542,
-0.28984112,0.25834284,0.22684456,0.19656397,0.16628339,0.14643708,
-0.12659078,0.106444,0.086297227,0.076081433,0.065865639,0.055683249,
-0.045500859,0.040629869,0.03575888,0.031127116,0.026495353,0.024316707,
-0.022138061,0.019934653,0.017731245,0.01619062,0.014649995,0.013104617,
-0.011559239,0.01030835,0.0090574603,0.0078583703,0.0066592804,0.0059099939,
-0.0051607074,0.0044159179,0.0036711284,0.0033605972,0.0030500659,0.0027368724,
-0.0024236788,0.0021708901,0.0019181013,0.0016732152,0.001428329,0.001428329,
-0.001428329
+          0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0f,0.0f,0.0f,0.0f,0.0f,
+0.0f,0.0088105211f,0.017621042f,0.020528086f,0.02343513f,0.026392526f,
+0.029349921f,0.033664215f,0.037978508f,0.042245031f,0.046511554f,0.055648902f,
+0.064786249f,0.07395196f,0.08311767f,0.10386151f,0.12460535f,0.14594447f,
+0.16728359f,0.20442288f,0.24156217f,0.27841272f,0.31526328f,0.35919335f,
+0.40312341f,0.44621342f,0.48930344f,0.53207715f,0.57485086f,0.61905294f,
+0.66325502f,0.7114532f,0.75965137f,0.8076253f,0.85559924f,0.89376042f,
+0.93192161f,0.9659608f,1.0f,0.99696894f,0.99393787f,0.99224825f,
+0.99055862f,0.96192825f,0.93329788f,0.90629723f,0.87929659f,0.87156435f,
+0.8638321f,0.85303543f,0.84223875f,0.85502674f,0.86781473f,0.88056734f,
+0.89331995f,0.89301593f,0.89271191f,0.86628263f,0.83985335f,0.80572933f,
+0.77160531f,0.73099612f,0.69038694f,0.64866608f,0.60694523f,0.56782227f,
+0.52869932f,0.48719362f,0.44568791f,0.40599882f,0.36630972f,0.32807542f,
+0.28984112f,0.25834284f,0.22684456f,0.19656397f,0.16628339f,0.14643708f,
+0.12659078f,0.106444f,0.086297227f,0.076081433f,0.065865639f,0.055683249f,
+0.045500859f,0.040629869f,0.03575888f,0.031127116f,0.026495353f,0.024316707f,
+0.022138061f,0.019934653f,0.017731245f,0.01619062f,0.014649995f,0.013104617f,
+0.011559239f,0.01030835f,0.0090574603f,0.0078583703f,0.0066592804f,0.0059099939f,
+0.0051607074f,0.0044159179f,0.0036711284f,0.0033605972f,0.0030500659f,0.0027368724f,
+0.0024236788f,0.0021708901f,0.0019181013f,0.0016732152f,0.001428329f,0.001428329f,
+0.001428329f
         };
 
     //Add multispectral bands to the temporary list
