@@ -113,7 +113,7 @@ bool RADImageIO::CanReadFile(const char* filename)
     }
 
   //Read header information
-  bool lResult = InternalReadHeaderInformation(lFileName, header_file, false);
+  bool lResult = InternalReadHeaderInformation(lFileName, header_file, true);
   header_file.close();
   return (lResult);
 }
@@ -408,7 +408,7 @@ bool RADImageIO::InternalReadHeaderInformation(const std::string& file_name, std
       {
       itkExceptionMacro(
         << "RAD : the value type '" << lStrCodePix <<
-        "' (second line) set in the header file is not reconized as correct value.");
+        "' (second line) set in the header file is not recognized as correct value.");
       }
     else
       {
@@ -416,7 +416,7 @@ bool RADImageIO::InternalReadHeaderInformation(const std::string& file_name, std
       }
     }
 
-  // Read "SENSCODAGE" information (optionnal)
+  // Read "SENSCODAGE" information (optional)
   file >> lString;
   if (lString.empty() == false)
     {
@@ -439,7 +439,7 @@ bool RADImageIO::InternalReadHeaderInformation(const std::string& file_name, std
           {
           itkExceptionMacro(
             << "RAD : the value SENSCODAGE '" << lString <<
-            "' set in the header file is not reconized as correct value. Possible values are INTEL or IEEE");
+            "' set in the header file is not recognized as correct value. Possible values are INTEL or IEEE");
           }
         else
           {
