@@ -111,19 +111,19 @@ public:
    // typedef std::reverse_iterator<char_iterator> reverse_iterator;
    typedef std::reverse_iterator<char_iterator> const_reverse_iterator;
 
-   /** Construtor from a standard string.
+   /** Constructor from a standard string.
     *@post `data()[size()] == '\0'`
     */
    string_view(std::string const& s)
       : m_size(s.size()), m_first(s.c_str())
       {}
-   /** Construtor from an ossim string.
+   /** Constructor from an ossim string.
     *@post `data()[size()] == '\0'`
     */
    string_view(ossimString const& s)
        : m_size(s.size()), m_first(s.c_str())
        {}
-   /** Construtor from an array of characters.
+   /** Constructor from an array of characters.
     * @post `data()[size()] == '\0'` <= the array is built with this kind of
     * syntax: `char const a[]="foobar";`
     */
@@ -131,7 +131,7 @@ public:
    string_view(char const (&array)[N])
       : m_size(N), m_first(&array[0])
       {}
-   /** Construtor from a pointer to a 0-terminated raw string.
+   /** Constructor from a pointer to a 0-terminated raw string.
     * @post `data()[size()] == '\0'`
     */
    string_view(char const* ptr)
@@ -144,7 +144,7 @@ public:
          assert(first <= last);
       }
 #endif
-   /** Construtor from an input iterator and a size.
+   /** Constructor from an input iterator and a size.
     * @post there is no guarantee `data()[size()] == '\0'`.
     */
    template <typename II>
@@ -152,7 +152,7 @@ public:
       : m_size(size_), m_first(first)
       {}
 
-   /** Construtor from a pair of input interators.
+   /** Constructor from a pair of input iterators.
     * @post there is no guarantee `data()[size()] == '\0'`.
     */
    template <typename II>
@@ -182,7 +182,7 @@ public:
    }
    template <typename String>
    bool belongs_to(String const& s) const{
-      return belongs_to(&*s.begin(), &*s.end());
+      return belongs_to(s.data(), s.data() + s.size());
    }
 
    size_type               size   () const { return m_size; }
@@ -496,7 +496,7 @@ part_range<splitter_on_delim> split_on(String const& str, char delim) {
  * \note For efficiency reasons, the function has been specialized for integral
  * floating point, and string types.
  * \note That alternative to `ossimString::toXxxx()` function has been defined
- * to support generic programing in `get()` and `add()` helper functions for
+ * to support generic programming in `get()` and `add()` helper functions for
  * keyword list.
  * \see `to_with_default()` for the version that never fails, but returns a
  * default value otherwise (being `T()` by default).
@@ -528,7 +528,7 @@ T to(string_view const& v, string_view const& context)
  * \note For efficiency reasons, the function has been specialized for integral
  * floating point, and string types.
  * \note That alternative to `ossimString::toXxxx()` function has been defined
- * to support generic programing in `get()` and `add()` helper functions for
+ * to support generic programming in `get()` and `add()` helper functions for
  * keyword list.
  * \see `to()` for the version that fails by throwing exceptions.
  */
@@ -556,6 +556,8 @@ namespace details {
      *
      * \return The string as an integer.
      * \throw std::runtime_error is the number cannot be converted.
+     * \todo Use a failure_policy in order to factorize code flavour (returns
+     * default value or throw an exception)
      */
     template <typename Int> inline Int to_integer(string_view const& v, string_view const& context)
     {
@@ -568,7 +570,6 @@ namespace details {
         bool is_negative = false;
         Int res = 0;
         if (it != end) {
-            // TODO: reject '-' with unsigned types
             switch (*it) {
                 case '-': is_negative = true; /*[[fallthrough]]*/
                 case '+': ++it;
@@ -609,7 +610,6 @@ namespace details {
         bool is_negative = false;
         Int res = 0;
         if (it != end) {
-            // TODO: reject '-' with unsigned types
             switch (*it) {
                 case '-': is_negative = true; /*[[fallthrough]]*/
                 case '+': ++it;
@@ -625,6 +625,74 @@ namespace details {
         return is_negative ? -res : res;
     }
 
+    /**
+     * \brief Internal generic string to unsigned integer conversion (w/ exception).
+     * Tries to convert the input string into a integer type. If the
+     * string doesn't represent an integer value, an exception is thrown.
+     * \tparam Int Integral type (In a perfect world, we'd used `enable_if` &
+     * co to restrict the code to integral types)
+     * \param[in] v  input string
+     * \param[in] context  context message for the exception thrown
+     *
+     * \return The string as an integer.
+     * \throw std::runtime_error is the number cannot be converted.
+     */
+    template <typename Int> inline Int to_uinteger(string_view const& v, string_view const& context)
+    {
+        // string_view::data() isn't compatible with strtol => we emulate it
+
+        // TODO: handle HEX, OCT, BIN, locales?
+        string_view::const_iterator it  = v.begin();
+        string_view::const_iterator end = v.end();
+
+        Int res = 0;
+        if (it != end) {
+            for ( ; it != end ; ++it) {
+                // only support arabic digits
+                if (!std::isdigit(*it)) {
+                    throw std::runtime_error("Cannot decode "+v+" as integer while " + context);
+                }
+                res  = 10 * res + *it - '0';
+            }
+        }
+        return res;
+    }
+
+    /**
+     * \brief Internal generic string to unsigned integer conversion (w/o exception).
+     * Tries to convert the input string into a integer type. If the
+     * string doesn't represent an integer value, the default value will be
+     * returned.
+     * \tparam Int Integral type (In a perfect world, we'd used `enable_if` &
+     * co to restrict the code to integral types)
+     * \param[in] v  input string
+     * \param[in] def  default value returned in the conversion isn't possible
+     *
+     * \return The string as an integer.
+     * \return `def` if the string cannot be converted to an integer value.
+     * \throw None
+     */
+    template <typename Int> inline Int to_uinteger(string_view const& v, Int const def)
+    {
+        // string_view::data() isn't compatible with strtol => we emulate it
+
+        // TODO: handle HEX, OCT, BIN, locales?
+        string_view::const_iterator it  = v.begin();
+        string_view::const_iterator end = v.end();
+
+        Int res = 0;
+        if (it != end) {
+            for ( ; it != end ; ++it) {
+                // only support arabic digits
+                if (!std::isdigit(*it)) {
+                   return def;
+                }
+                res  = 10 * res + *it - '0';
+            }
+        }
+        return res;
+    }
+
     /**
      * \brief Internal generic string to float conversion (w/ exception).
      * Tries to convert the input string into a floating point type. If the
@@ -704,13 +772,22 @@ namespace details {
 // Note: specialization doesn't support default arguments, but default argument
 // T() will still work.
 
-OSSIM_GENERATE_CONV(to_integer, char);
-OSSIM_GENERATE_CONV(to_integer, short);
-OSSIM_GENERATE_CONV(to_integer, int);
-OSSIM_GENERATE_CONV(to_integer, unsigned int);
-OSSIM_GENERATE_CONV(to_integer, long);
-OSSIM_GENERATE_CONV(to_float,   ossim_float32);
-OSSIM_GENERATE_CONV(to_float,   ossim_float64);
+OSSIM_GENERATE_CONV(to_integer,  char);
+OSSIM_GENERATE_CONV(to_uinteger, unsigned char);
+OSSIM_GENERATE_CONV(to_integer,  signed char);
+OSSIM_GENERATE_CONV(to_uinteger, unsigned short);
+OSSIM_GENERATE_CONV(to_integer,  short);
+OSSIM_GENERATE_CONV(to_integer,  int);
+OSSIM_GENERATE_CONV(to_uinteger, unsigned int);
+OSSIM_GENERATE_CONV(to_integer,  long);
+OSSIM_GENERATE_CONV(to_uinteger, unsigned long);
+#if defined(HAS_LONG_LONG) // TODO: add this configure option
+OSSIM_GENERATE_CONV(to_integer,  long long);
+OSSIM_GENERATE_CONV(to_uinteger, unsigned long long);
+#endif
+OSSIM_GENERATE_CONV(to_float,    float);
+OSSIM_GENERATE_CONV(to_float,    double);
+OSSIM_GENERATE_CONV(to_float,    long double);
 #undef OSSIM_GENERATE_CONV
 
 template <> inline std::string to<std::string>(string_view const& v, string_view const& /*context*/)
