@@ -26,11 +26,13 @@
 #include "itkLogger.h"
 #include "otbWrapperMacros.h"
 #include "otbWrapperInputImageParameter.h"
+#include "otbWrapperInputImageListParameter.h"
 #include "otbWrapperOutputImageParameter.h"
 #include "otbWrapperComplexInputImageParameter.h"
 #include "otbWrapperComplexOutputImageParameter.h"
 #include "otbWrapperDocExampleStructure.h"
 #include "itkMersenneTwisterRandomVariateGenerator.h"
+#include "OTBApplicationEngineExport.h"
 
 namespace otb
 {
@@ -44,7 +46,7 @@ namespace Wrapper
  *
  * \ingroup OTBApplicationEngine
  */
-class ITK_ABI_EXPORT Application: public itk::Object
+class OTBApplicationEngine_EXPORT Application: public itk::Object
 {
 public:
   /** Standard class typedefs. */
@@ -402,6 +404,93 @@ public:
    */
   std::vector<std::string> GetParameterStringList(std::string parameter);
 
+
+  /** 
+   * Set the input image parameter as an ImageBase * instead
+   * of filename. Useful to connect pipelines between different
+   * application instances.
+   * \in parameter The parameter key
+   * \in inputImage ImageBase pointer to use as input
+   * \throw itk::Exception if parameter is not found or not an
+   * InputImageParameter
+   */
+  void SetParameterInputImage(std::string parameter, InputImageParameter::ImageBaseType * inputImage);
+
+  /**
+   * Get the output image parameter as an ImageBase * instead
+   * of writing to disk. Useful to connect pipelines between different
+   * application instances.
+   * \in parameter The parameter key
+   * \return The ImageBase * to the output image
+   * \throw itk::Exception if parameter is not found or not an
+   * OutputImageParameter
+   */
+  OutputImageParameter::ImageBaseType * GetParameterOutputImage(std::string parameter);
+
+  /** 
+   * Set the input complex image parameter as an ImageBase * instead
+   * of filename. Useful to connect pipelines between different
+   * application instances.
+   * \in parameter The parameter key
+   * \in inputImage ImageBase pointer to use as input
+   * \throw itk::Exception if parameter is not found or not an
+   * ComplexInputImageParameter
+   */
+  void SetParameterComplexInputImage(std::string parameter, ComplexInputImageParameter::ImageBaseType * inputImage);
+
+  /**
+   * Get the complex output image parameter as an ImageBase * instead
+   * of writing to disk. Useful to connect pipelines between different
+   * application instances.
+   * \in parameter The parameter key
+   * \return The ImageBase * pointer to the output image
+   * \throw itk::Exception if parameter is not found or not an
+   * ComplexOutputImageParameter
+   */
+  ComplexOutputImageParameter::ImageBaseType * GetParameterComplexOutputImage(std::string parameter);
+
+  /**
+   * Add an image to an InputImageList parameter as an ImageBase
+   * pointer instead of reading from file. Useful to connect pipelines
+   * between different application instances.
+   * \in parameter The parameter key
+   * \in img The ImageBase * of the image to add
+   * \throw itk::Exception if parameter is not found or not an
+   * InputImageList parameter
+   */ 
+  void AddImageToParameterInputImageList(std::string parameter, InputImageListParameter::ImageBaseType * img);
+
+  /**
+   * Set the nth image of an InputImageList parameter as an ImageBase pointer
+   * instead of reading from file. Useful to connect pipelines
+   * between different application instances.
+   * \in parameter The parameter key
+   * \in id Position at which to set the ImageBase pointer
+   * \in img The ImageBase * of the image to add
+   * \throw itk::Exception if parameter is not found or not an
+   * InputImageList parameter or if id is out of bounds
+   */ 
+  void SetNthParameterInputImageList(std::string parameter, const unsigned int &id, InputImageListParameter::ImageBaseType * img);
+
+  /**
+   * Clear all images from an InputImageList parameter.
+   *
+   * \in parameter The parameter key
+   * \throw itk::Exception if parameter is not found or not an
+   * InputImageList parameter
+   */ 
+  void ClearParameterInputImageList(std::string parameter);
+
+  /**
+   * Get the number of images in an InputImageList parameter.
+   * \in parameter The parameter key
+   * \return The number of images
+   * \throw itk::Exception if parameter is not found or not an
+   * InputImageList parameter
+   */ 
+  unsigned int GetNumberOfElementsInParameterInputImageList(std::string parameter);
+
+  
   /* Get an image value
    *
    * Can be called for types :
