@@ -1137,6 +1137,140 @@ std::vector<std::string> Application::GetParameterStringList(std::string paramet
   return ret;
 }
 
+void Application::SetParameterInputImage(std::string parameter, InputImageParameter::ImageBaseType * inputImage)
+{
+  Parameter* param = GetParameterByKey(parameter);
+
+  InputImageParameter* paramDown = dynamic_cast<InputImageParameter*> (param);
+  
+  if (paramDown)
+    {
+    paramDown->SetImage(inputImage);
+    }
+  else
+    {
+    itkExceptionMacro(<<parameter << "parameter can't be casted to InputImageParameter");
+    }
+}
+
+OutputImageParameter::ImageBaseType * Application::GetParameterOutputImage(std::string parameter)
+{
+  Parameter* param = GetParameterByKey(parameter);
+  
+  OutputImageParameter* paramDown = dynamic_cast<OutputImageParameter*> (param);
+  
+  if (paramDown)
+    {    
+    return paramDown->GetValue();
+    }
+  else
+    {
+    itkExceptionMacro(<<parameter << "parameter can't be casted to OutputImageParameter");
+    }
+}
+
+
+void Application::SetParameterComplexInputImage(std::string parameter, ComplexInputImageParameter::ImageBaseType * inputImage)
+{
+  Parameter* param = GetParameterByKey(parameter);
+
+  ComplexInputImageParameter* paramDown = dynamic_cast<ComplexInputImageParameter*> (param);
+  
+  if (paramDown)
+    {
+    paramDown->SetImage(inputImage);
+    }
+  else
+    {
+    itkExceptionMacro(<<parameter << "parameter can't be casted to ComplexInputImageParameter");
+    }
+}
+
+ComplexOutputImageParameter::ImageBaseType * Application::GetParameterComplexOutputImage(std::string parameter)
+{
+  Parameter* param = GetParameterByKey(parameter);
+  
+  ComplexOutputImageParameter* paramDown = dynamic_cast<ComplexOutputImageParameter*> (param);
+  
+  if (paramDown)
+    {    
+    return paramDown->GetValue();
+    }
+  else
+    {
+    itkExceptionMacro(<<parameter << "parameter can't be casted to ComplexOutputImageParameter");
+    }
+}
+
+void Application::AddImageToParameterInputImageList(std::string parameter, InputImageListParameter::ImageBaseType * img)
+{
+  Parameter* param = GetParameterByKey(parameter);
+  
+  InputImageListParameter * paramDown = dynamic_cast<InputImageListParameter *>(param);
+  
+  if(paramDown)
+    {
+    paramDown->AddImage(img);
+    }
+  else
+    {
+    itkExceptionMacro(<<parameter << "parameter can't be casted to InputImageListParameter");
+    }
+  
+}
+
+void Application::SetNthParameterInputImageList(std::string parameter, const unsigned int &id, InputImageListParameter::ImageBaseType * img)
+{
+  Parameter* param = GetParameterByKey(parameter);
+
+  InputImageListParameter * paramDown = dynamic_cast<InputImageListParameter *>(param);
+
+  if(paramDown)
+    {
+    paramDown->SetNthImage(id,img);
+    }
+  else
+    {
+    itkExceptionMacro(<<parameter << "parameter can't be casted to InputImageListParameter");
+    }
+
+}
+
+void Application::ClearParameterInputImageList(std::string parameter)
+{
+  Parameter* param = GetParameterByKey(parameter);
+
+  InputImageListParameter * paramDown = dynamic_cast<InputImageListParameter *>(param);
+
+  if(paramDown)
+    {
+    paramDown->ClearValue();
+    }
+  else
+    {
+    itkExceptionMacro(<<parameter << "parameter can't be casted to InputImageListParameter");
+    }
+
+}
+
+unsigned int Application::GetNumberOfElementsInParameterInputImageList(std::string parameter)
+{
+  Parameter* param = GetParameterByKey(parameter);
+
+  InputImageListParameter * paramDown = dynamic_cast<InputImageListParameter *>(param);
+
+  if(paramDown)
+    {
+    return paramDown->Size();
+    }
+  else
+    {
+    itkExceptionMacro(<<parameter << "parameter can't be casted to InputImageListParameter");
+    }
+
+}
+
+
 
 FloatVectorImageType* Application::GetParameterImage(std::string parameter)
 {
@@ -1421,7 +1555,7 @@ Application::IsApplicationReady()
       // return false when does not have value and:
       //  - The param is root
       //  - The param is not root and belonging to a Mandatory Group
-      //    wich is activated
+      //    which is activated
       if ( !this->HasValue(*it)  && IsMandatory(*it) )
         {
         if( GetParameterByKey(*it)->IsRoot() )
