@@ -34,7 +34,7 @@ namespace Wrapper
  *
  * \ingroup OTBQtWidget
  */
-class ITK_ABI_EXPORT QtWidgetEmptyParameter : public QtWidgetParameterBase
+class OTBQtWidget_EXPORT QtWidgetEmptyParameter : public QtWidgetParameterBase
 {
   Q_OBJECT
 
